<?php
/*
 * Myra template functions.
 *
 * These functions are called to include the pieces and parts of a myra template
 * into a page before displaying.
 *
 */


/* Functions returning theme settings */

function templateDefaultTheme() {
	// Specify a theme name here if this template prefers a certain theme.
	// If not specified, the site configuration setting DEFAULT_THEME will be used.
	// This setting can be over overridden by the user (if other themes exist).
	return '';
}

function templateDefaultOrientation() {
	return 'portrait';
	//return 'landscape';
}

function templatePageType() {
	// The page type is the name of a css file in the themes css directory.
	// The current page types in the myra/themes/myra/css directory are:
	// 'page','menu','report','error', 'dialog-page', and 'index'.
	return 'page';
}

function templateAutoEdit() {
	// Return true if system is to automatically add the edit region to a file.
	// Return false if the region to edit is defined in template.html.
	//return true;
	return false;
}


/* Functions returning code for page HEAD section. */

function templateIncludeCSS() {
	$logo_file_name = "page-logo.{$GLOBALS['Theme']}.jpg";
	$logo_url = "{$GLOBALS['BASE_URL']}{$GLOBALS['MYRA_LOCAL']}/images/$logo_file_name";
?>
<style>
.header{
	background-image:url(<?php echo $logo_url; ?>);
}
.tracker-container {
	margin:12px 0px 0px 0px;
	height:40px;
}
.tracker {
	position:absolute;
	bottom:15px;
	left:0px;
	width:100%;
	background:#F0F0F0;
}
.tracker ul {
	width:380px;
	margin:1px auto;
	padding:2px 0px;
	color:#333;
	text-align:center;
}
.tracker li {
	display:inline-block;
	margin:0px 9px;
}

@media print {
	.tracker { position:static; bottom:auto; background:none; margin:30px 0px 0px 0px; }
	.tracker ul { border:none; width:auto; text-align:left; font-size:9px; line-height:11px; padding:3px 0px; }
	.tracker li { display:block; margin:0; padding:0; }
	.header { background-image:none; }
	.content { min-height:0; padding: 0; margin:0; }
	.footer { margin-top:0; }
}
</style>

<?php
}

function templateIncludeJS() {
	// Nothing
?>
<?php
}


/* Functions returning body HTML */

function templateIncludeHeader() {
?>
<div class="header">
<h1><a href="/"><?php echo $GLOBALS['ORG_TITLE']; ?></a></h1>
</div><!-- .header -->

<?php
}

function templateIncludeLeftSidebar() {
?>
<div class="left-sidebar"
<?php include "{$GLOBALS['MYRA_LOCAL_PATH']}/inc/main_menu.php"; ?>
</div>

<?php
}

function templateIncludeRightSidebar() {
?>
<div class="right-sidebar">
</div><!-- .right-sidebar -->
<?php 
}

function templateIncludeFooter() {
?>
<div class="footer">
<?php if (strlen($GLOBALS['COPYRIGHT']) > 0) { echo '<div class="copyright">'.$GLOBALS['COPYRIGHT']."</div>\n"; } ?>
</div><!-- .footer -->

<?php
}


/* Callback functions for creating and saving template pages. */

function templateBeforeNew($html) {
	// Function called before creating a new file from this template.
	return $html;
}

function templateAfterNew() {
	// Function called after creating a new file from this template.
}

function templateBeforeSave($html) {
	// Function called before saving a file created from this template.
	return templateTracker($html);
}

function templateAfterSave() {
	// Function called after saving a file created from this template.

	// Return true to force the browser to reload the page after saving the file.
	// Return anything else, or nothing, shows the edits on the page w/o refreshing.
	return true;
}

/* custom functions for this template */

function templateTracker($html) {
	// Substitute tracking info into placeholders in the HTML source.

	function increment($matches) {
		return $matches[1].strval(intval($matches[2]) + 1).$matches[3];
	}

	function tracker($matches) {
		// $matches is an array of matched 
		$html = $matches[2];
		$html = preg_replace_callback('|(<span class="revision">)(.*?)(</span>)|','increment',$html);
		$html = preg_replace('|(<span class="last-update">)(.*?)(</span>)|','${1}'.date("Y-m-d H:i:s").'${3}',$html);
		$html = preg_replace('|(<span class="last-update-user">)(.*?)(</span>)|','${1}'.$GLOBALS['User'].'${3}',$html);
		return $matches[1].$html.$matches[3];
	}

	return preg_replace_callback('|(<div class="tracker">)(.*?)(</div><!-- .tracker -->)|s','tracker',$html);
}
?>
