<?php
/*
 * Create a new file from a template.
 *
 * Intended for ajax usage only. Current directory obtained from session variables.
 */

include_once 'myra/lib/config.php';
include_once 'myra/lib/class.Session.php';
include_once 'myra/lib/class.Template.php';
include_once 'myra/lib/lib.common.php';
include_once 'myra/lib/lib.auth.php';
include_once 'myra/lib/lib.file.php';

$session = Session::getInstance();

is_ajax_request() or exit_forbidden();

$key	  = isset($_POST['key'])	? $_POST['key']		: null;
$new_name = isset($_POST['new_name'])	? $_POST['new_name']	: '';
$title    = isset($_POST['title'])	? $_POST['title']	: '';
$template = isset($_POST['template'])	? $_POST['template']	: $GLOBALS['MYRA_TEMPLATE'];

switch_context_to_key($key) or exit_forbidden();

can_edit_current_dir() or exit_forbidden();

if (! $session->curr_dir) {
	warn(basename(__FILE__).": no curr_dir set. request_uri: {$_SERVER['REQUEST_URI']}");
	exit_result(false,'Corrupted data. Cannot make your new file. Please refresh your screen and try again.');
	exit;
}

$new_name = sanitize_filename($new_name);
$title = sanitize_title($title);
$template = sanitize_filename($template);

$session->template = $template;

// Set template variables
$GLOBALS['PageTitle'] = $title;
$GLOBALS['Copyright'] = "© ".date('Y')." {$GLOBALS['ORG_NAME']}, {$GLOBALS['ORG_URL']}";
$GLOBALS['Template'] = $template;
$GLOBALS['Theme'] = my_theme();
$GLOBALS['URL'] = $_SERVER['HTTP_REFERER'];
$GLOBALS['User'] = $GLOBALS['REMOTE_USER'];
$GLOBALS['Date'] = date("Y-m-d H:i:s");

include_once 'myra/lib/class.TemplateParts.php';
$tp = new TemplateParts($template);

// Automatically add template file extension to name if missing.
$ext = preg_match('/\\.'.$tp->template_extension().'/i',$new_name) ? '' : '.'.$tp->template_extension();

$file_name = $new_name.$ext;
$file = $session->curr_dir.DIRECTORY_SEPARATOR.$file_name;
if (file_exists($file)) {
	exit_result(false,array('errmsg'=>"The file $new_name already exists. Please choose a different name.",'key'=>new_context()));
}

// Set template variable for current file now that we know it.
$GLOBALS['File'] = $file;

// Merge template
$tpl = new Template($template);
$html = $tpl->merge($GLOBALS);
$html = $tp->beforeNew($html) or exit_result(false,'Could not create a new template page.');
write_file($file,$html) or exit_result(false,'Could not create a new file.');
$tp->afterNew();
exit_result(true,array('file_name'=>$file_name));
?>
