<?php
/*
 * Save folder index information (header, footer, privileges)
 *
 * Intended for ajax usage only. Current directory obtained from session variables.
 */

include_once 'myra/lib/config.php';
include_once 'myra/lib/class.Session.php';
include_once 'myra/lib/class.IndexDb.php';
include_once 'myra/lib/lib.common.php';
include_once 'myra/lib/lib.auth.php';
include_once 'myra/lib/lib.file.php';

$session = Session::getInstance();

is_ajax_request() or exit_forbidden();

$key			= isset($_POST['key'])			? $_POST['key']			: null;
$new_name		= isset($_POST['new_name'])		? $_POST['new_name']		: null;

$title			= isset($_POST['title'])		? $_POST['title']		: null;
$description		= isset($_POST['description'])		? $_POST['description']		: null;
$keywords		= isset($_POST['keywords'])		? $_POST['keywords']		: null;
$header			= isset($_POST['header'])		? $_POST['header']		: null;
$footer			= isset($_POST['footer'])		? $_POST['footer']		: null;
$upload_notify_email	= isset($_POST['upload_notify_email'])	? $_POST['upload_notify_email']	: null;
$reset_sort_order	= bool($_POST['reset_sort_order']);

switch_context_to_key($key) or exit_forbidden();

if ($new_name) {
	// Create new folder
	$folder_name = sanitize_filename($new_name);
	if ($folder_name && can_edit_current_dir() && create_folder($folder_name,$session->curr_dir)) {
		create_new_context($folder_name);
	}
	else {
		exit_result(false,"Cannot create a new folder $folder_name");
	}
}

// If parameters are equal to their default values, set them back to null.
if (preg_match("|<h1>(&nbsp;)?</h1>|",$header)) $header = null;
if (preg_match("|<p>(&nbsp;)?</p>|",$footer)) $footer = null;

$idb = new IndexDb($session->curr_dir);
if ($header !== null) $saved_header = $idb->header(sanitize_html($header));
if ($footer !== null) $saved_footer = $idb->footer(sanitize_html($footer));
if ($title !== null) $idb->option('title',sanitize_title($title));
if ($description !== null) $idb->option('description',sanitize_description($description));
if ($keywords !== null) $idb->option('keywords',sanitize_keywords($keywords));
if ($upload_notify_email !== null) $idb->option('upload_notify_email',sanitize_email_address($upload_notify_email));
if ($reset_sort_order) $idb->option('thumb-sort-order','');	// remove saved sort order

foreach (array('guest_can_upload','upload_allow_images','upload_allow_documents','upload_allow_video','upload_allow_music','upload_allow_anything','gallery_default_view','guest_can_sort') as $opt) {
	$idb->option($opt,bool($_POST[$opt]));
}

if ($folder_name && $idb->save()) {
	exit_result(true,array('folder_name'=>$folder_name));
}
elseif ($saved_header == $header && $saved_footer == $footer && $idb->save()) {
	exit_result(true);
}
else {
	exit_result(false,'Edits were not saved. Please try again later.');
}
?>
