<?php
/*
 * Save a page
 *
 * Intended for ajax usage only. Current directory obtained from session variables.
 *
 * Unlike save-file.php, only the contents of an html page are changed - the portion
 * between the tags defined by MYRA_EDIT_DELIMITER_BEGIN and MYRA_EDIT_DELIMITER_END
 * configuration parameters.
 */

include_once 'myra/lib/config.php';
include_once 'myra/lib/class.Session.php';
include_once 'myra/lib/lib.common.php';
include_once 'myra/lib/lib.file.php';
include_once 'myra/lib/lib.auth.php';

$session = Session::getInstance();

is_ajax_request() or exit_forbidden();

$key	 = isset($_POST['key'])		? $_POST['key']		: null;
$content = isset($_POST['content'])	? $_POST['content']	: '';

switch_context_to_key($key) or exit_forbidden();

can_edit_current_file() or exit_forbidden();

$content = sanitize_html($content);
if (! $content) {
	warn(basename(__FILE__).": no content to save to $file. request_uri: {$_SERVER['REQUEST_URI']}");
	exit_result(false,"Content was empty.");
}

$file = $session->curr_dir.DIRECTORY_SEPARATOR.$session->curr_file;
$view_start_time = (isset($_POST['time']) && $_POST['time']) ? $_POST['time'] : $session->view_start_time;

clearstatcache();
if (filemtime($file) > $view_start_time) {
	exit_result(false,"File has changed since you started viewing it. Please refresh your screen and try again.");
}

$old = file_get_contents($file);
if ($old === false) {
	exit_result(false,"File has vanished.");
}

/* Set Template variables in globals for template functions */
/* TODO: Consolidate/standardize template variables here with ajax/new-page.php and ajax/template.php */
$GLOBALS['Template'] = $session->template;
$GLOBALS['Theme'] = my_theme();
$GLOBALS['URL'] = $_SERVER['HTTP_REFERER'];
$GLOBALS['File'] = $file;
$GLOBALS['User'] = $GLOBALS['REMOTE_USER'];
$GLOBALS['Date'] = date("Y-m-d H:i:s");

include_once 'myra/lib/class.TemplateParts.php';
$tp = new TemplateParts($session->template);

$new = preg_replace('/(.*?'.$tp->editable_begin().').*?('.$tp->editable_end().'.*)/si', '$1'."\n".$content."\n".'$2', $old);

if (strlen($new) > 0 && strcmp($new,$old) != 0) {
	$new = $tp->beforeSave($new) or exit_result(false,'Cannot save file.');

	archive_file($file,"Before being saved from web by: ".$session->user->username()." ({$_SERVER['REMOTE_ADDR']})");

	write_file($file,$new) or exit_result(false,"Error writing file.");

	$refresh = $tp->afterSave() === true ? true : false;

	exit_result(true,array(msg=>"File saved.",refresh=>$refresh,time=>time()));
}

// Enter failure reasons into log.
if (strlen($new) <= 0) warn('save-page: No content in $new to save file');
if (strlen($new) > 0 && strcmp($new,$old) == 0) warn('save-page: no substitutions were made to the old content');
debug('save-page: template='.$session->template.', $tp->editable_begin()='.$tp->editable_begin().', $tp->editable_end()='.$tp->editable_end());

exit_result(false,"No changes were made.");
?>
