<?php
/*
 * Delete a file dialog
 *
 * Current file obtained from session variables.
 * The thumbnail and slide will be deleted if the file is a picture.
 * This presents a confirmation dialog, the actual deletion is done
 * in the ajax routine.
 */

include_once 'myra/lib/config.php';
include_once 'myra/lib/class.Session.php';
include_once 'myra/lib/lib.common.php';
include_once 'myra/lib/lib.auth.php';

$session = Session::getInstance();

$title = "Delete File";
$page_type = 'dialog';

authenticate_user() or die_unauthenticated();
if (context_id($_SERVER['HTTP_REFERER']) != $session->context) {
        switch_context($_SERVER['HTTP_REFERER'])
	 or exit_dialog_error("Could not obtain permission for this operation. Please refresh your screen and try again.");
}
can_edit_current_dir() or die_unauthorized();

$filename = $session->curr_file;
if (strlen($filename) <= 0) {
	exit_dialog_error("Missing file name.");
}

$file = $session->curr_dir.DIRECTORY_SEPARATOR.$filename;
if (! file_exists($file)) {
	exit_dialog_error("File does not exist.");
}

$view_start_time = (isset($_GET['time']) && $_GET['time']) ? $_GET['time'] : $session->view_start_time;

clearstatcache();
if (filemtime($file) > $view_start_time) {
	exit_dialog_error("The file has changed since you started viewing it. Please refresh your screen and try again.");
}

$key = new_context();

$script = <<<End_Of_Javascript
<script type="text/javascript">
//<![CDATA[
jQuery(function($){
	// Register key being used.
	parent.myra.registerKey($('input[name=key]').val());

	$('form').submit(function(event){
		event.preventDefault(); 
		$.ajax({url:$(this).attr('action'),data:$(this).serialize(),type:$(this).attr('method'),dataType:'json'})
		 .done(function(result){
			if (result['success']) {
				$('form').html(result['data']['msg']);
				parent.myra.scheduleRedirect('./');
			}
			else {
				alert('The page was not deleted. '+result['errmsg']);
			}
		})
		 .fail(function(){
			alert('An error occurred when trying to delete the file. Please refresh and try again.');	// e.g. 403 forbidden errors
		})
		.always(function(){
			parent.jQuery.fancybox.close();
		});
	});

	// Allow esc key to close dialog.
	$(document).keyup(function(e){ if (e.which == 27) parent.jQuery.fancybox.close(); });

	// Focus on first field
	$('input:visible:first').focus();
});
//]]>
</script>

End_Of_Javascript;
?>
<?php include 'myra/inc/dialog_preamble.php'; ?>
<div class="dialog">

<h1><?php echo $title; ?></h1>

<form action="<?php echo $GLOBALS['MYRA']; ?>/ajax/delete-file.php" method="post">
<input type="hidden" name="key" value="<?php echo $key; ?>" />
<input type="hidden" name="confirm" value="yes" />
<p>Please confirm: Do you want to delete this file <strong><?php echo $filename; ?></strong>?</p>
<div class="dialog-buttons">
<input type="submit" value="Yes" />
<input type="reset" value="No" onclick="parent.jQuery.fancybox.close();" />
</div>
</form>

</div><!-- .dialog -->
<?php include 'myra/inc/dialog_epilog.php'; ?>
