<?php
/*
 * Edit index.
 *
 * This edits the index database header, footer, and user privileges.
 * This presents a dialog, the actual saving of edits is done in the ajax routine.
 */

include_once 'myra/lib/config.php';
include_once 'myra/lib/class.Session.php';
include_once 'myra/lib/class.IndexDb.php';
include_once 'myra/lib/lib.common.php';
include_once 'myra/lib/lib.auth.php';

$session = Session::getInstance();

authenticate_user() or die_unauthenticated();
if (context_id($_SERVER['HTTP_REFERER']) != $session->context) {
        switch_context($_SERVER['HTTP_REFERER'])
	 or exit_dialog_error("Could not obtain permission for this operation. Please refresh your screen and try again.");
}
can_edit_current_dir() or exit_forbidden();

$key = new_context();

$idb = new IndexDb($session->curr_dir);
$u_theme = $GLOBALS['MYRA_THEMES'].'/'.rawurlencode(my_theme());
$h_header = sanitize_html($idb->header()) or $h_header = '<h1></h1>';
$h_footer = sanitize_html($idb->footer()) or $h_footer = '<p></p>';

$h_dir = sanitize_html(basename($session->curr_dir));

$title = "Edit Folder";
$page_type = 'dialog';

$script = <<<End_Of_Javascript
<script src="{$GLOBALS['MYRA']}/js/jquery.mtabify.js" type="text/javascript"></script>
<script type="text/javascript">
jQuery(function($){
	$('#edit_info,#edit_header,#edit_footer,#edit_admin,#edit_security').addClass('panel').mTabify('Info,Header,Footer,Admin,Security');
});
</script>
<script src="{$GLOBALS['MYRA']}/js/jquery.filter_input.min.js" type="text/javascript"></script>
<script src="{$GLOBALS['MYRA']}/js/tinymce/jscripts/tiny_mce/jquery.tinymce.js" type="text/javascript"></script>
<script type="text/javascript">
//<![CDATA[
jQuery(function($){
	// Register key being used.
	parent.myra.registerKey($('input[name=key]').val());

	$('form').submit(function(event){
		/* stop form from submitting normally */
		event.preventDefault(); 
		$.ajax({url:$(this).prop('action'),data:$(this).serialize(),type:$(this).prop('method'),dataType:'json'})
		 .done(function(result){
			var header = $('textarea[name=header]').val(),
			    footer = $('textarea[name=footer]').val();
			if (result['success']) {
				// post results, close window.
				try {
					parent.jQuery('.index-header').html(header);
					parent.jQuery('.index-footer').html(footer);
				}
				catch(e) {
					alert('Your edits were saved but there was a problem showing the changes on your screen. Please refresh your page.');
				}
			}
			else {
				alert('The index header or footer were not saved. '+result['errmsg']);
			}
		})
		 .fail(function(){
			alert('An error occurred when trying to save the folder.');	// e.g. 403 forbidden errors
		})
		 .always(function(){
			parent.jQuery.fancybox.close();
		});
	});

	// Attach tinyMCE editor to header and footer input.
	// Note: assign width and height to textarea elements to prevent tinymce from ignoring them on 2nd or more elements.
	// Also, make edit area as wide as the page content to make spacing appear the same.
	$('#edit_header textarea, #edit_footer textarea')
	.css({'width':'644px','height':'275px'})	// tinymce bug requires this for 2 or more textareas.
	.tinymce({
		// Location of TinyMCE script
		script_url : "{$GLOBALS['MYRA']}/js/tinymce/jscripts/tiny_mce/tiny_mce_gzip.php",
		convert_urls : false,

		theme : "advanced",
		theme_advanced_buttons1 : "cut,copy,paste,pastetext,pasteword,|,undo,redo,|,formatselect,|,bold,italic,underline,strikethrough,|,forecolor,|,bullist,numlist,outdent,indent,|,charmap,|,link,unlink,cleanup,code,|,spellchecker,iespell",
		theme_advanced_buttons2 : "",
		theme_advanced_buttons3 : "",
		theme_advanced_toolbar_location : "top",
		theme_advanced_toolbar_align : "left",
		theme_advanced_statusbar_location : "none",
		plugins : "paste,code,spellchecker,iespell",

		// Skin options
		skin : "o2k7",
		skin_variant : "silver",

		content_css : '{$u_theme}/css/edit-tinymce.css'
	});

	// Spoof HTML5 pattern attribute on textarea's until there is browser support.
	$('input[pattern],textarea[pattern]').each(function(){
		$(this).filter_input({regex:$(this).attr('pattern')});
	});

	// Allow esc key to close dialog.
	$(document).keyup(function(e){ if (e.which == 27) parent.jQuery.fancybox.close(); });

	// Activate header tab
	$('.tabs a[href="#edit_header"]').click();
});
//]]>
</script>

End_Of_Javascript;
?>
<?php include 'myra/inc/dialog_preamble.php'; ?>
<div class="dialog">
<h1><?php echo $title; ?></h1>
<form action="<?php echo $GLOBALS['MYRA']; ?>/ajax/save-folder.php" method="post">
<input type="hidden" name="key" value="<?php echo $key; ?>" />

<div id="edit_info">
<div class="section">
<h2>Name</h2>
<h3><?php echo $h_dir; ?></h3>
</div>
<div class="section">
<h2>Title</h2>
<label>Enter a title for the directory of this folder that is displayed in the browser's title bar and in its history.
<textarea name="title" pattern="[\w\s~!@#$%^&*()_+={}|:<>?/.,-]"><?php echo sanitize_html($idb->option('title')); ?></textarea></label>
</div><!-- .section -->
<div class="section">
<h2>Description</h2>
<label>Enter a description for the directory of this folder that can be used by the search engine.
<textarea name="description" pattern="[\w\s~!@#$%^&*()_+={}|:<>?/.,-]"><?php echo sanitize_html($idb->option('description')); ?></textarea></label>
</div><!-- .section -->
<div class="section">
<h2>Keywords</h2>
<label>Enter a comma-separated list of words that can be used by the search engine to index this directory.
<textarea name="keywords" pattern="[\w\s.,-]"><?php echo sanitize_html($idb->option('keywords')); ?></textarea></label>
</div><!-- .section -->
</div><!-- .edit_info -->

<div id="edit_header">
 <label>Header<textarea name="header"><?php echo $h_header; ?></textarea></label>
</div><!-- .edit_header -->

<div id="edit_footer">
 <label>Footer<textarea name="footer"><?php echo $h_footer; ?></textarea></label>
</div><!-- .edit_footer -->

<div id="edit_admin">
<div class="section">
<h2>Uploads</h2>
 <label class="checkbox"><input type="checkbox" name="guest_can_upload" <?php echo $idb->option('guest_can_upload') ? 'checked="checked"' : ''; ?> />Guests (non-editors) can upload files to this folder.</label>
 <div class="checkboxes">
 <label class="checkbox"><input type="checkbox" name="upload_allow_images" <?php echo $idb->option('upload_allow_images') ? 'checked="checked"' : ''; ?> />Allow images (.gif,.jpeg,.png,.pdf,...) to be uploaded.</label>
 <label class="checkbox"><input type="checkbox" name="upload_allow_documents" <?php echo $idb->option('upload_allow_documents') ? 'checked="checked"' : ''; ?> />Allow documents (.docx, .xlsx,...) to be uploaded.</label>
 <label class="checkbox"><input type="checkbox" name="upload_allow_video" <?php echo $idb->option('upload_allow_video') ? 'checked="checked"' : ''; ?> />Allow video (.mp4,.wmv,.avi,...) to be uploaded.</label>
 <label class="checkbox"><input type="checkbox" name="upload_allow_music" <?php echo $idb->option('upload_allow_music') ? 'checked="checked"' : ''; ?> />Allow music (.mp3) to be uploaded.</label>
 <label class="checkbox"><input type="checkbox" name="upload_allow_anything" <?php echo $idb->option('upload_allow_anything') ? 'checked="checked"' : ''; ?> />Allow any file to be uploaded. (Not recommended)</label>
 </div>
 <label>Email notification of uploads to <input type="text" name="upload_notify_email" value="<?php echo sanitize_email_address($idb->option('upload_notify_email')); ?>" placeholder="Enter email addresse(s) separated by commas." /></label>
</div><!-- .section -->
<div class="section">
<h2>Gallery</h2>
 <label class="checkbox"><input type="checkbox" name="gallery_default_view" <?php echo $idb->option('gallery_default_view') ? 'checked="checked"' : ''; ?> />Set gallery view to be the default view of folder.</label>
 <label class="checkbox"><input type="checkbox" name="guest_can_sort" <?php echo $idb->option('guest_can_sort') ? 'checked="checked"' : ''; ?> />Allow guests (non-editors) to rearrange thumbnail order.</label>
 <label class="checkbox"><input type="checkbox" name="reset_sort_order" />Reset thumbnail sort order to original order.</label>
</div><!-- .section -->
</div><!-- .edit_admin -->
<div id="edit_security">
<div class="section">
<h2>Editors</h2>
<ul>
<li><?php echo join("</li>\n<li>",$idb->editors()); ?></li>
</ul>
<p>Editors can change files in this folder and those under this folder. To change editors, please notify <a href="<?php echo $GLOBALS['SUPPORT_URL'].'?subject=Change%20editors%20for%20'.urlencode($_SERVER['HTTP_REFERER']); ?>">support</a>.</p>
</div><!-- .section -->
</div><!-- .edit_security -->

<div class="dialog-buttons">
 <input type="submit" value="Save" />
 <input type="reset" value="Cancel" onclick="parent.jQuery.fancybox.close();" />
</div>

</form>
</div><!-- .dialog -->
<?php include 'myra/inc/dialog_epilog.php'; ?>
