<?php
/*
 * New page
 *
 * This creates a new file in the current directory.
 * This presents a dialog, the actual saving of edits is done in the ajax routine.
 */

include_once 'myra/lib/config.php';
include_once 'myra/lib/class.Session.php';
include_once 'myra/lib/lib.common.php';
include_once 'myra/lib/lib.auth.php';
include_once 'myra/lib/lib.select_options.php';

$session = Session::getInstance();

authenticate_user() or die_unauthenticated();
if (context_id($_SERVER['HTTP_REFERER']) != $session->context) {
        switch_context($_SERVER['HTTP_REFERER'])
	 or exit_dialog_error("Could not obtain permission for this operation. Please refresh your screen and try again.");
}
can_edit_current_dir() or exit_forbidden();

$key = new_context();

$title = "New Page";
$page_type = 'dialog';
$script = <<<End_Of_Javascript
<script type="text/javascript">
//<![CDATA[
jQuery(function($){
	// Register key being used.
	parent.myra.registerKey($('input[name=key]').val());

	$('form').submit(function(event){
		event.preventDefault(); 
		$.ajax({url:$(this).attr('action'),data:$(this).serialize(),type:$(this).attr('method'),dataType:'json'})
		 .done(function(result){
			if (result['success']) {
				parent.myra.scheduleRedirect(result['data']['file_name']+'?edit=yes');
				parent.jQuery.fancybox.close();		// always close as key has been used even on error return
			}
			else {
				if (result['data']) {
					alert('The new page was not saved. '+result['data']['errmsg']);
					$('input[name=key]').val(result['data']['key']);
					$('input[name=new_name]').focus();
				}
				else {
					alert('The new page was not saved. '+result['errmsg']);
					parent.jQuery.fancybox.close();		// always close as key has been used even on error return
				}
			}
		})
		 .fail(function(){
			alert('An error occurred when trying to save the file. Please refresh and try again.');	// e.g. 403 forbidden errors
			parent.jQuery.fancybox.close();		// always close as key has been used even on error return
		});
	});

	// Spoof HTML5 pattern attribute on textarea's until there is browser support.
	$('input[pattern],textarea[pattern]').each(function(){
		$(this).filter_input({regex:$(this).attr('pattern')});
	});

	// Identify reqired fields.
	$('input[required]').after('<img src="'+myra.cfg('theme_images')+'/required.png" title="This field entry is required.">');

	// Suggest file name from title.
	var non_web_char = /[\W]+/g, trim_char = /[-]$/,
	make_file_name = function(e){ $('#new_name').val($('#title').val().replace(non_web_char,'-').replace(trim_char,'').toLowerCase()); };
	$('#title').keyup(make_file_name).change(make_file_name);

	// Show template descriptions.
	var add_icon_to_description = function() {
		$(this).prepend('<img src="{$GLOBALS['MYRA_TEMPLATES']}/'+$('select[name=template]').val()+'/icon.png" />');
	};
	$('select[name=template]').change(function(){
		$('#template_description').html('').load('{$GLOBALS['MYRA_TEMPLATES']}/'+$(this).val()+'/description.html',add_icon_to_description);
	});
	$('#template_description').html('').load('{$GLOBALS['MYRA_TEMPLATES']}/'+$('select[name=template]').val()+'/description.html',add_icon_to_description);

	// Allow esc key to close dialog.
	$(document).keyup(function(e){ if (e.which == 27) parent.jQuery.fancybox.close(); });

	// Focus on first field.
	$('input:visible:first').focus();
});
//]]>
</script>

End_Of_Javascript;
?>
<?php include 'myra/inc/dialog_preamble.php'; ?>
<div class="dialog">
<h1><?php echo $title; ?></h1>
<div class="sections">
<div class="section">
<form action="<?php echo $GLOBALS['MYRA']; ?>/ajax/new-page.php" method="post">
<input type="hidden" name="key" value="<?php echo $key; ?>" />
<h2>Title</h2>
<label>Enter a title for the directory of this folder that is displayed in the browser's title bar and in its history.
<input type="text" name="title" id="title" value=""></label>
</div>
<div class="section">
<h2>Name</h2>
<label>Enter a "web" type name that is all lower case text with words separated by dashes (-).
<input type="text" name="new_name" id="new_name" value="" placeholder="Enter a name for the new web page." required="required" /></label>
</div>
<div class="section">
<h2>Template</h2>
<label>Select the template for this web page.
<select name="template" id="template" placeholder="Please choose a template type.">
        <?php print select_options(template_list(),$GLOBALS['MYRA_TEMPLATE']); ?>
  </select></label>
<div id="template_description"></div>
</div><!-- .section -->
</div><!-- .sections -->
<div class="dialog-buttons">
<input type="submit" value="Save" />
<input type="reset" value="Cancel" onclick="parent.jQuery.fancybox.close();" />
</div>
</form>
</div><!-- .sections -->
</div><!-- .dialog -->
<?php include 'myra/inc/dialog_epilog.php'; ?>
