<?php
#ini_set('memory_limit','40M');

/**
 * img -- create, cache, and return a thumb or a slide of an image
 *
 * Thumbnails and slides are automatically derived from the original image
 * and cached in an index database (usually a hidden .index directory in
 * source directory).
 */

$SECURITY_STRICT_IMG_SRC = true;	// restrict image src paths to current directory

include_once 'myra/lib/config.php';
include_once 'myra/lib/class.Session.php';
include_once 'myra/lib/class.IndexDb.php';
include_once 'myra/lib/lib.common.php';

$session = Session::getInstance();

$src		= isset($_REQUEST['src'])	? $_REQUEST['src']	: '';	// required
$thumb		= bool($_REQUEST['thumb']);
$slide		= bool($_REQUEST['slide']);
$image		= bool($_REQUEST['image']);
$refresh	= bool($_REQUEST['refresh']);
$rotate = null;
if (isset($_REQUEST['rotate'])) {
	// Add all rotate values together into one value.
	if (is_array($_REQUEST['rotate'])) {
		$rotate = 0;
		foreach ($_REQUEST['rotate'] as $r) {
			$rotate += intval($r);
		}
	}
	else {
		$rotate = intval($_REQUEST['rotate']);
	}
}

// Security checks for Myra.
if (context_id($_SERVER['HTTP_REFERER']) != $session->context) {
	switch_context($_SERVER['HTTP_REFERER']) or exit_forbidden("src=$src, session=".$session->context);
}

// Sanitize src parameter.
$src = rawurldecode($src);
if (preg_match('|\.\./|',$src)) {
	warn("Relative path names using /../ are not allowed. src=$src");
	if ($thumb) {
		header('Content-type: image/png');
		print file_get_contents($GLOBALS['MYRA_THEMES_PATH'].'/'.my_theme().'/images/thumb-403.png');
		exit;
	}
	exit_forbidden();
}
if ($SECURITY_STRICT_IMG_SRC) $src = basename($src);

// Set full path of image src.
$src = $session->curr_dir . DIRECTORY_SEPARATOR . $src;

if (! is_readable($src)) {
	if ($thumb) {
		header('Content-type: image/png');
		print file_get_contents($GLOBALS['MYRA_THEMES_PATH'].'/'.my_theme().'/images/thumb-404.png');
	}
	else {
		header("HTTP/1.0 404 Not Found");
	}
	exit;
}

// Get image.
$idb = new IndexDb(dirname($src));

if ($refresh) {
	$idb->refresh($src);
}

if ($rotate !== null) {
	$idb->rotate($src,$rotate);
}

if ($thumb) {
	header('Content-type: '.$idb->thumb_mime_type($src));
	print $idb->thumb($src);
	exit;
}

if ($slide) {
	header('Content-type: '.$idb->slide_mime_type($src));
	print $idb->slide($src);
	exit;
}

if ($image) {
	header('Content-type: '.$idb->image_mime_type($src));
	print $idb->image($src);
	exit;
}
exit;
?>
