/**
 * Scripts to edit a page
 *
 * Div's with a class of 'editable' are replaced with an editor allowing user to
 * change and save their contents.
 *
 * @require myra.js
 * @require jQuery
 * @require jquery.cookie.js
 * @require TinyMCE
 */

(function($,myra){
	var EDIT_AREA_ID_PREFIX = 'myra_editable_',	// random string
	MYRA_AJAX = myra.cfg('ajax'),
	MYRA_SCRIPTS = myra.cfg('scripts'),
	MYRA_THEME_CSS = myra.cfg('theme_css'),

	encodeHTML = function(html){
		return html.replace(/&/g,'&amp;').replace(/</g,'&lt;').replace(/>/g,'&gt;').replace(/"/g,'&quot;');
	},

	get_editkey = function($editarea){
		// Get security token key.
		$editarea.data('myraKey',null);	// ensure old key cleared

		$.ajax({
			url: MYRA_AJAX+'/geteditkey.php',
			data: {t:myra.time()},
			type: 'GET',
			dataType:'json'
		})
		.done(function(result){
			if (result['success']) {
				$editarea.data('myraKey',result.data.key);
			}
			else {
				alert('Cannot edit file. '+result.errmsg);
				hide_editor($editarea);
			}
		})
		.fail(function(){
			alert('Cannot get permission to edit this page from server. Please refresh your screen and try again.');
			hide_editor($editarea);
		});
	},

	save = function($editarea){
		// Save editor changes on server.
		if (! $editarea.data('myraKey')) {
			throw new Error("Edit key was not returned from the server.");
			//alert('Problems communicating to server. Please refresh your browser and try again.');	// insulting, means edits lost
			return;
		}
		$.ajax({
			url:MYRA_AJAX+'/save-page.php',
			data: {content:$editarea.find('textarea').val(), key:$editarea.data('myraKey'), time:myra.time()},
			type:'POST',
			dataType:'json'
		})
		.done(function(result){
			if (result['success']) {
				// Post edits to document
				$editarea.prev('.editable').html( $editarea.find('textarea').val() );

				if (result['data']['time']) myra.time(result['data']['time']);

				if (result['data']['refresh']) {
					// Reload page to get how it was actually saved on server (possible error or server modifications).
					// Remove possible auto-edit flag from url.
					var re = /[?&]edit=(yes|1)/i;
					if (location.href.match(re)) {
						location.href = location.href.replace(/[?&]edit=(yes|1)/i,'');
					}
					else {
						location.reload(true);
					}
				}
			}
			else {
				alert('The file was not saved. '+result.errmsg);
			}
		})
		.fail(function(){	// e.g. 403 forbidden errors
			alert('An error occurred when trying to save the file.');
		})
		.always(function(){
			hide_editor($editarea);
		});
	},

	cancel = function($editarea){
                // Notify server that security key can be released.
		if ($editarea.data('myraKey')) $.post(MYRA_AJAX+"/cancel.php",{key:$editarea.data('myraKey')});

		hide_editor($editarea);
	};

	get_editarea = function(index){
		var editarea_id = EDIT_AREA_ID_PREFIX + index;
		return $('#'+editarea_id);
	},

	make_editarea = function($el,index){
		var editarea_id = EDIT_AREA_ID_PREFIX + index,
		// Create textarea for editing content.
		adjust_width = 18, adjust_height = 120, min_height = 250,	// TODO: allow themes to adjust these
		$editarea = $('<div id="'+editarea_id+'" class="editarea" style="display:none"><form><textarea style="width:'+($el.parent().width()+adjust_width)+'px;height:'+Math.max($el.parent().height()-adjust_height,min_height)+'px;"></textarea></form></div>');

		$editarea.insertAfter($el);

		// Fill form field with editable content.
		$editarea.find('textarea').val($el.html());

		return $editarea;
	},

	attach_editor = function($editarea){
		// Attach editor to $editarea
		$editarea.find('textarea').tinymce({

			// Location of TinyMCE script
			script_url : MYRA_SCRIPTS+"/tinymce/jscripts/tiny_mce/tiny_mce_gzip.php",
			convert_urls : false,
			gecko_spellcheck : true,
			spellcheck : true,

			// General options
			theme : "advanced",
			plugins : "autolink,spellchecker,iespell,pagebreak,style,layer,table,save,advhr,advimage,advlink,inlinepopups,insertdatetime,preview,media,searchreplace,contextmenu,paste,fullscreen,noneditable,visualchars,nonbreaking,autoresize",

			// Theme options
			theme_advanced_buttons1 : "save,cancel,|,preview,|,cut,copy,paste,pastetext,pasteword,|,undo,redo,|,cleanup,removeformat,|,search,replace,|,spellchecker,iespell,|,link,unlink,image,media,insertdate,inserttime,charmap,|,code,fullscreen",
			theme_advanced_buttons2 : "styleprops,formatselect,fontselect,fontsizeselect,|,bold,italic,underline,strikethrough,|,sub,sup,|,justifyleft,justifycenter,justifyright,|,bullist,numlist,|,outdent,indent,blockquote",
			theme_advanced_buttons3 : "tablecontrols,|,insertlayer,moveforward,movebackward,absolute,|,hr,advhr,nonbreaking,pagebreak,|,forecolor,backcolor,|,visualaid,visualchars",

			theme_advanced_toolbar_location : "top",
			theme_advanced_toolbar_align : "left",
			theme_advanced_statusbar_location : "none",
			// Uncomment next to show status bar at bottom. Messes up Full Screen, but allow resizing
			//theme_advanced_statusbar_location : "bottom",
			theme_advanced_resizing : true,

			// Skin options
			skin : "o2k7",
			skin_variant : "silver",

			// Example content CSS (should be your site CSS)
			content_css : MYRA_THEME_CSS+'/edit-tinymce.css',

			// Save options
			//save_enablewhendirty : true,
			save_onsavecallback : function(){save($editarea)},
			save_oncancelcallback : function(){cancel($editarea)},
			init_instance_callback : function(ed){
				$('#'+$editarea.prop('id')+'_tbl').css({width:'100%'});
			},

			// Editor object settings
			// The following corrects a tinymce bug of not saving changed layer positions upon re-editing a document.
			setup: function(ed){
				ed.onPreProcess.add(function(ed,o){
					// Patch to save layers position
					$('.mceItemVisualAid',o.node).removeAttr('data-mce-style');
					return true;
				});
			}
		});
	},

	new_editarea = function($editable,index){
		// Create new work area in document for editor.
		var $editarea = make_editarea($editable,index);
		$.cookie('TinyMCE_mce_'+index+'_size',null);	// Remove saved editor size.
		attach_editor($editarea);
		return $editarea;
	},

	show_editor = function($editarea){
		get_editkey($editarea);
		$editarea.show().prev('.editable').hide();
	},

	hide_editor = function($editarea){
		if (window.tinymce && $editarea.find('textarea').tinymce().plugins.fullscreen.fullscreenEditor) {
			// hide fullscreen editor
			// following does not work to quit full screen mode.
			//$('#'+editarea_id+' textarea').tinymce().execCommand('mceFullScreen',false);
			$editarea.find('textarea').tinymce().plugins.fullscreen.fullscreenEditor.hide();
			$('#mce_fullscreen_container').remove();	// remove dangling fullscreen div, force tinymce to regenerate it next time
			// ### TODO: scrollbars/height do not return to normal after fullscreen yet. (following does not completely work)
			//$('.editable').css({height:'auto'});	// adjust height back to normal
			//$('.content').css({height:'auto'});	// adjust height back to normal
			//$('.footer').css({display:'block'});	// adjust height back to normal
			//$('body').css({height:'auto'});	// adjust height back to normal
			$('body').css({overflow:'auto'});	// turn on scrollbars again
		}
		$editarea.hide().prev('.editable').show();
	};

	// Extend myra
	myra.editPage = function(){

		//if ($('.editable').length == 0) {
		//	alert('Cannot edit this page as editable regions have not been defined.');
		//	return false;
		//}

		// Dynamically load editor software.
		if (! $.isFunction($.fn.tinymce)) {
			$.ajax({
				dataType: 'script',
				cache: true,
				url: MYRA_SCRIPTS+'/tinymce/jscripts/tiny_mce/jquery.tinymce.js'
			})
			.done(function(){
				myra.editPage();
			});
			return;
		}

		$('.editable').each(function(index){
			var $editarea = get_editarea(index);

			if ($editarea.length == 0) {
				// First time, setup editor to edit this editable content.
				$editarea = new_editarea($(this),index);
				show_editor($editarea);
				return;
			}

			// Toggle display of editor window
			if ($editarea.is(':visible')) {
				hide_editor($editarea);
			}
			else {
				show_editor($editarea);
			}
		});
	};
})(jQuery,myra);
