/**
 * Javascript scripts common to most pages.
 *
 * @require jQuery
 * @require jQuery.cookie
 * @require window.MYRA definition of root directory.
 */

(function($,window){
	var MYRA = window.MYRA ? window.MYRA : null,
	    BASE = window.BASE ? window.BASE : MYRA,
	    TIME = window.TIME ? window.TIME : (new Date()).getTime()/1000;	// unix time stamp
	if (typeof MYRA != 'string') throw new Error('Missing MYRA path setting.');

	var myra = window.myra ? window.myra : {};

	$.extend(myra,{
		// Configuration
		cfg : function(prop){
			if (prop == null) prop = 'path';
			switch (prop.toLowerCase()) {
			case 'path' : return BASE;
			case 'scripts' : return BASE + '/js';
			case 'ajax' : return BASE + '/ajax';
			case 'themes' : return BASE + '/themes';
			case 'theme' : return $.cookie('myraTheme') ? $.cookie('myraTheme') : 'default';
			case 'theme_path' : return myra.cfg('themes') + '/' + encodeURIComponent(myra.cfg('theme'));
			case 'theme_css' : return myra.cfg('theme_path') + '/css';
			case 'theme_images' : return myra.cfg('theme_path') + '/images';
			case 'theme_scripts' : return myra.cfg('theme_path') + '/js';
			default: throw new Error('Bad myra property: '+prop);
			}
		},
		// View time (server's time clock)
		time : function(time){
			if (time && time > 0) TIME = time;	// set time page was last viewed
			return TIME;				// return time page was last viewed
		},

		// Page orientation methods.
		changeToPortrait : function(){
			$('body').removeClass('landscape').addClass('portrait');
			$.cookie('myraOrient','P',{path:'/'});
			myra.resetLandscapeWidth();
		},
		changeToLandscape : function(){
			$('body').removeClass('portrait').addClass('landscape');
			$.cookie('myraOrient','L',{path:'/'});
			myra.setLandscapeWidth();
		},
		setLandscapeWidth : function() {
			// This sets the width of the window to contain the largest high-level table.
			// We do this because spreadsheets pasted into the editor become tables which
			// can overrun the width of the landscape page that is set in the css file.
			var winw = $(window).width(),
				leftw = $('.left-sidebar').outerWidth(),
				margin = 16,
				maxw = 0;
			$('.editable>table').each(function(){
				var w = $(this).outerWidth() + leftw + margin;
				if (w > maxw) {
					maxw = w;
				}
			});
			if (maxw > 0) {
				$('.page').css('min-width',maxw);
			}
		},
		resetLandscapeWidth : function() {
			$('.page').css('min-width',0);
		}
	});

	// Dialog assist handlers
	// As of 12/2011, browsers do not reliably process the window.unload events.
	// Chrome not at all, FF balks if a screen refresh is involved, even after a timeout.
	// The following provides a failsafe alternative. The dialogCleanup can be called in
	// a window.unload event and/or in a dialog close event such as fancybox.onClose().
	var refresh_scheduled = false,		// flag set by dialogs
	redirect_scheduled = '',
	upload_key = null,
	active_keys = [],
	uploaded_files = [];

	$.extend(myra,{
		dialogCleanup : function(){
			this.releaseKeys();
			if (upload_key) this.closeUpload();
			if (redirect_scheduled) this.redirect();
			else if (refresh_scheduled) this.refresh();
		},
		scheduleRefresh : function(){
			refresh_scheduled = true;
		},
		refresh : function(){
			setTimeout(function(){window.location.reload();},500);
			refresh_scheduled = false;
		},
		scheduleRedirect : function(url){
			redirect_scheduled = url;
		},
		redirect : function(){
			setTimeout(function(){window.location.href = redirect_scheduled;},500);
			refresh_scheduled = false;
		},
		registerKey : function(key){
			active_keys.push(key);
		},
                releaseKey : function(key){
                        $.post(myra.cfg('ajax')+"/cancel.php",{key:key});
			active_keys = active_keys.filter(function(active_key){ return key != active_key; });
		},
                releaseKeys : function(){
                        if (active_keys.length > 0) {
                                $.post(myra.cfg("ajax")+"/cancel.php",{key:active_keys});
				active_keys = [];
                        }
                },
		startUpload : function(key){
			upload_key = key;
		},
		registerUpload : function(file){
			uploaded_files.push(file);
		},
		closeUpload : function(){
                        $.post(myra.cfg("ajax")+"/close_upload.php",{key:upload_key,files:uploaded_files});
			uploaded_files = [];
			upload_key = null;
		}
	});

	$(function(){
		if (! $('body').hasClass('portrait') && ! $('body').hasClass('landscape')) {
			if ($.browser.msie || $.browser.opera)	pageshow = 'load';	// have no pageshow event
			else					pageshow = 'pageshow';	// use pageshow so event fires upon using back button

			// Setup event to set page to proper orientation, even on cached pages redisplay.
			$(window).on(pageshow,function(event){
				if ($.cookie('myraOrient') == 'L') {
					myra.changeToLandscape();
				}
				else {
					myra.changeToPortrait();
				}
			});
		}
		else if ($('body').hasClass('landscape')) {
			myra.setLandscapeWidth();
		}
	});

	// Expose
	window.myra = myra;
})(jQuery,window);
