<?php
/**
 * Image transformations
 *
 * Requires GD library.
 * Debian requires ImageMagick too. (2010)
 * As with all GD apps, image size is restricted by php.ini setting
 * memory_limit (default 8M).
 */

//ini_set('memory_limit','40M');

class Img {
	private $src = null;

	private $curr_img = 0;
	private $imgs = array();

	private $mime_type = null;

	public function __construct($src) {
		$this->src = realpath($src);
		$this->imgs[$this->curr_img] = @imagecreatefromstring(file_get_contents($this->src));
		if (! $this->imgs[$this->curr_img]) {
			trigger_error("Cannot open image: $src",E_USER_WARNING);
			return false;
		}
	}
	public function __destruct() {
		if ($this->imgs[$this->curr_img]) {
			// Clean up.
			imagedestroy($this->imgs[$this->curr_img]);
		}
	}

	public function rotate($angle) {
		if (! $this->imgs[$this->curr_img]) return false;
		$new_img = $this->curr_img == 0 ? 1 : 0;
		$this->imgs[$new_img] = imagerotate($this->imgs[$this->curr_img],$angle,0);
		imagedestroy($this->imgs[$this->curr_img]);
		$this->curr_img = $new_img;
		return true;
	}

	public function magnify($magnification) {
		if (! $this->imgs[$this->curr_img]) return false;
		$new_img = $this->curr_img == 0 ? 1 : 0;
		$w = imagesx($this->imgs[$this->curr_img]);
		$h = imagesy($this->imgs[$this->curr_img]);
		$new_w = intval($w * $magnification);
		$new_h = intval($h * $magnification);
		$this->imgs[$new_img] = imagecreatetruecolor($new_w,$new_h);
		imagecopyresized($this->imgs[$new_img],$this->imgs[$this->curr_img],0,0,0,0,$new_w,$new_h,$w,$h);
		imagedestroy($this->imgs[$this->curr_img]);
		$this->curr_img = $new_img;
		return true;
	}

	public function resize($maxwidth=null,$maxheight=null,$minscale=null) {
		if (! $this->imgs[$this->curr_img]) return false;
		$new_img = $this->curr_img == 0 ? 1 : 0;
		$iw = imagesx($this->imgs[$this->curr_img]);
		$ih = imagesy($this->imgs[$this->curr_img]);
		// Allow resize to be at least a minimum size
		$w = $minscale != null ? $iw*$minscale : $iw;
		$h = $minscale != null ? $ih*$minscale : $ih;
		// Allow images to be constrained by specifying only one axis.
		if ($maxwidth == null) $maxwidth = $w;
		if ($maxheight == null) $maxheight = $h;
		$dim = $this->getProportionalImageSize($w,$h,$maxwidth,$maxheight);
		$this->imgs[$new_img] = imagecreatetruecolor($dim['width'],$dim['height']);
		imagecopyresampled($this->imgs[$new_img],$this->imgs[$this->curr_img],0,0,0,0,$dim['width'],$dim['height'],$iw,$ih);
		imagedestroy($this->imgs[$this->curr_img]);
		$this->curr_img = $new_img;
		return true;
	}

	public function thumbnail($maxwidth=null,$maxheight=null) {
		// Like resize(), this resizes images for thumbnails.
		// Speed trumps quality in determining criteria for resizing images to thumbnails.
		// Note: this version is the same as resize() above.
		return $this->resize($maxwidth,$maxheight);
	}

	//From www.php.net
	public function getProportionalImageSize($src_w, $src_h, $max_w, $max_h){
	   $return_val['width']=$src_w;
	   $return_val['height']=$src_h;
	   if($max_w<$src_w || $max_h<$src_h){
	       $return_val['width']=$max_w;
	       $return_val['height']=$max_h;
	       if($src_w>=$src_h) $return_val['height']=($max_w*$src_h)/$src_w;
	       else $return_val['width']=($max_h*$src_w)/$src_h;
	   }
	   return $return_val;
	}

	public function mime($type=null) {
		if ($type !== null) {
			$this->mime_type = $type;
			return $type;
		}
		if ($this->mime_type === null) {
			// use same mime type as src
			$ext = strtolower(preg_match('/\.(\w{3,4})$/',$this->src,$matches) ? $matches[1] : '');
			switch ($ext) {
			case 'png':	$this->mime_type = 'image/png'; break;
			case 'gif':	$this->mime_type = 'image/gif'; break;
			case 'jpg':	$this->mime_type = 'image/jpeg'; break;
			case 'jpeg':	$this->mime_type = 'image/jpeg'; break;
			case 'tiff':	$this->mime_type = 'image/tiff'; break;
			case 'tif':	$this->mime_type = 'image/tiff'; break;
			default:	$this->mime_type = 'image/png';
			}
		}
		return $this->mime_type;
	}

	public function save($filepath) {
		switch ($this->mime()) {
		case 'image/jpeg': return imagejpeg($this->imgs[$this->curr_img],$filepath);
		case 'image/gif':  return imagegif($this->imgs[$this->curr_img],$filepath);
		case 'image/png':  return imagepng($this->imgs[$this->curr_img],$filepath);
		case 'image/tiff': return imagepng($this->imgs[$this->curr_img],$filepath);
		default:           return imagepng($this->imgs[$this->curr_img],$filepath);
		}
	}
	public function show() {
		// trick save to sending output to browser
		return $this->save(null);
	}
}

/*
 * 7/2010 Debian does not bundle full GD library because of library leaks. Include workaround using ImageMagick.
 */

if ( !function_exists( 'imagerotate' ) ) {
    function imagerotate( $source_image, $angle, $bgd_color ) {
        $angle = 360-$angle; // GD rotates CCW, imagick rotates CW
        $temp_src = tempnam('/tmp','myra1');
        $temp_dst = tempnam('/tmp','myra2');
        if (!imagepng($source_image,$temp_src)){
            return false;
        }
        $imagick = new Imagick();
        $imagick->readImage($temp_src);
        $imagick->rotateImage(new ImagickPixel($bgd_color?$bgd_color:'black'), $angle);
        $imagick->writeImage($temp_dst);
        //trigger_error( 'imagerotate(): could not write to ' . $file1 . ', original image returned', E_USER_WARNING );
        $result = imagecreatefrompng($temp_dst);
        unlink($temp_dst);
        unlink($temp_src);
        return $result;
    }
}

?>
