<?php
/**
 * Session data
 *
 * Derived from: http://us.php.net/manual/en/function.session-start.php
 */

/* Examples:

// We get the instance
$data = Session::getInstance();

// Let's store datas in the session
$data->nickname = 'Someone';
$data->age = 18;

// Let's display datas
printf( '<p>My name is %s and I\'m %d years old.</p>' , $data->nickname , $data->age );

// TRUE
var_dump( isset( $data->nickname ));

// We destroy the session
$data->destroy();

// FALSE
var_dump( isset( $data->nickname ));

*/

/* Myra requires User object for session decoding. */
include_once dirname(__FILE__).'/class.User.php';

class Session
{
    const SESSION_STARTED = TRUE;
    const SESSION_NOT_STARTED = FALSE;
   
    // The state of the session
    private $sessionState = self::SESSION_NOT_STARTED;
   
    // THE only instance of the class
    private static $instance;
   
   
    private function __construct() {}
   
   
    /**
    *    Returns THE instance of 'Session'.
    *    The session is automatically initialized if it wasn't.
    *   
    *    @return    object
    **/
   
    public static function getInstance()
    {
        if ( !isset(self::$instance))
        {
            self::$instance = new self;
        }
       
        self::$instance->startSession();
       
        return self::$instance;
    }
   
   
    /**
    *    (Re)starts the session.
    *   
    *    @return    bool    TRUE if the session has been initialized, else FALSE.
    **/
   
    public function startSession()
    {
        if ( $this->sessionState == self::SESSION_NOT_STARTED )
        {
            $this->sessionState = session_start();
            if ($this->sessionState)
	    {
                if (isset($_SESSION['new_session']))
		{
		    $_SESSION['new_session'] = false;
                }
		else
		{
		    $_SESSION['new_session'] = true;
		}
            }
        }
       
        return $this->sessionState;
    }
   
    /**
    *    Determine if this is the first time session variables used.
    *   
    *    @return    bool    TRUE if the session was created for this program, else FALSE.
    **/
   
    public function is_new_session()
    {
        return $_SESSION['new_session'] ? true : false;
    }
   
    /**
    *    Stores datas in the session.
    *    Example: $instance->set('foo','bar');
    *   
    *    @param    name    Name of the datas.
    *    @param    value    Your datas.
    *    @return    void
    **/
   
    public function set( $name , $value )
    {
        $_SESSION[$name] = $value;
    }
   
   
    /**
    *    Gets datas from the session.
    *    Example: echo $instance->get('foo');
    *   
    *    @param    name    Name of the datas to get.
    *    @return    mixed    Datas stored in session.
    **/
   
    public function get( $name )
    {
        if ( isset($_SESSION[$name]))
        {
            return $_SESSION[$name];
        }
    }
   
    /**
    *    Stores datas in the session.
    *    Example: $instance->foo = 'bar';
    *   
    *    @param    name    Name of the datas.
    *    @param    value    Your datas.
    *    @return    void
    **/
   
    public function __set( $name , $value )
    {
	return $this->set($name, $value);
    }
   
   
    /**
    *    Gets datas from the session.
    *    Example: echo $instance->foo;
    *   
    *    @param    name    Name of the datas to get.
    *    @return    mixed    Datas stored in session.
    **/
   
    public function __get( $name )
    {
	return $this->get($name);
    }
   
   
    public function __isset( $name )
    {
        return isset($_SESSION[$name]);
    }
   
   
    public function __unset( $name )
    {
        unset( $_SESSION[$name] );
    }
   
   
    /**
    *    Destroys the current session.
    *   
    *    @return    bool    TRUE is session has been deleted, else FALSE.
    **/
   
    public function destroy()
    {
        if ( $this->sessionState == self::SESSION_STARTED )
        {
            $session_name = session_name();
            $this->sessionState = !session_destroy();
            ##unset( $_SESSION );
	    // Adapted from php.net.
	    $_SESSION = array();
	    if (isset($_COOKIE[$session_name])) {
		    setcookie($session_name, '', time()-42000, '/');
		    unset($_COOKIE[$session_name]);
	    }
           
            return !$this->sessionState;
        }
       
        return FALSE;
    }
}
?>
