<?php
/**
 * Template file merge
 *
 * Usage:
 * 	$tpl = new Template('templatefile');
 *	$arr['var1'] = $val1;
 *	$arr['var2'] = $val2;
 *	$arr['var3'] = $val3;
 *	print $tpl->merge($arr);
 *
 * The merge() method will return the empty string if template file cannot be found.
 *
 * If a field value is empty and the field is preceeded or followed by HTML tags without
 * any whitespace between, then the surrounding tags are gobbled too unless they are
 * <td> or <th> tags.
 *
 * For example, if $arr['var1'] = ''; then
 *	<div><p>{var1}</p></div>
 * becomes
 *	<div></div>
 * whereas
 *	<div><p>
 *	{var1}
 *	</p></div>
 * becomes
 *	<div><p>
 *
 *	</p></div>
 *
 * Template field names consist of only characters and digits, no white-space or delimiters.
 * Template fields for variables that are not defined in the array are passed through untouched.
 */ 

include_once dirname(__FILE__).'/config.php';
include_once dirname(__FILE__).'/lib.common.php';

class Template {
	private $template = null;
	private $bgn = '{';		// can be any non-character delimiter like '$'
	private $end = '}';		// can be any non-character delimiter or empty
	private $template_file;

	public function __construct($template) {
		if ($GLOBALS['MYRA_TEMPLATE_DELIMITER_BEGIN']) $this->bgn = $GLOBALS['MYRA_TEMPLATE_DELIMITER_BEGIN'];
		if ($GLOBALS['MYRA_TEMPLATE_DELIMITER_END'])   $this->end = $GLOBALS['MYRA_TEMPLATE_DELIMITER_END'];

		$this->template_file = "{$GLOBALS['MYRA_TEMPLATES_PATH']}/$template/template.html";
		if (! is_readable($this->template_file)) {
			$this->template_file = "{$GLOBALS['MYRA_TEMPLATES_PATH']}/$template/template.php";
		}
	}

	public function merge($vals) {
		if (!$this->template && !$this->get_template()) return '';

		$b = $this->bgn == '$' ? '\$' : $this->bgn;
		$e = $this->end == '$' ? '\$' : $this->end;

		// Match prefix and suffix tags if surrounding field without any white space in between.
		// TODO: first $b is not technically just one character. Translate [^>$b] to negative assertion.
		return preg_replace("|(<(\\w+)[^>$b]*>)?($b(\\w+)$e)(</?\\w+\\s*/?>)?|e",'$this->sub($vals,"$4","$1","$5")',$this->template);
	}

	private function get_template() {
		$this->template = file_get_contents($this->template_file);
		return $this->template ? true : false;
	}

	private function sub(&$vals,$field,$prefix='',$suffix='') {
		if (array_key_exists($field,$vals)) {
			// Substitute field value.
			return $prefix.$vals[$field].$suffix;
		}
		else {
			// Field name not valid, return original string.
			return $prefix.$this->bgn.$field.$this->end.$suffix;
		}
	}
}
?>
