<?php
/**
 * Template parts
 *
 * Usage:
 * 	$tp = new TemplateParts($template_name);
 *	$header = $tp->header();
 *	...
 *
 * This provides an interface to the local template functions. It gets the template parts
 * for an html document which are wrapped around the document to create a full myra document
 * with menus and such. It also provides an interface to the template event handlers called
 * before and after creating a document and saving it.
 *
 * At this time, the global $Template must be defined before including this file.
 */ 

include_once dirname(__FILE__).'/config.php';
include_once dirname(__FILE__).'/lib.common.php';
include_once dirname(__FILE__).'/class.Session.php';

$template_functions = "{$GLOBALS['MYRA_TEMPLATES_PATH']}/{$GLOBALS['Template']}/functions.php";
if (! is_readable($template_functions)) {
	$GLOBALS['Template'] = $GLOBALS['MYRA_TEMPLATE'];
	$template_functions = "{$GLOBALS['MYRA_TEMPLATES_PATH']}/{$GLOBALS['Template']}/functions.php";
	warn(basename(__FILE__).": Bad template name: {$GLOBALS['Template']} changed to default {$GLOBALS['MYRA_TEMPLATE']}. request_uri: {$_SERVER['REQUEST_URI']}");
}
if (is_readable($template_functions)) {
	include_once $template_functions;
}
else {
	warn(basename(__FILE__).": Bad template name: {$GLOBALS['Template']}. request_uri: {$_SERVER['REQUEST_URI']}");
}

class TemplateParts {
	private $_template_file = '';
	private $_template_ext = '';

	public function __construct($template=null) {
	}

	public function template_file() {
		if ($this->_template_file) return $this->_template_file;
		$session = Session::getInstance();
		$f = glob("{$GLOBALS['MYRA_TEMPLATES_PATH']}/".$session->template."/template.*");
		if ($f !== false && count($f) > 0) {
			$this->_template_file = $f[0];
		}
		return $this->_template_file;
	}

	public function template_extension() {
		if ($this->_template_ext) return $this->_template_ext;
		$this->_template_ext = substr($this->template_file(), strrpos($this->template_file(), ".")+1);
		return $this->_template_ext;
	}

	public function orientation() {
		$orientation = function_exists('templateDefaultOrientation') ? templateDefaultOrientation() : null
		 or $orientation = $_COOKIE['myraOrient'] == 'L' ? 'landscape' : null
		 or $orientation = $_COOKIE['myraOrient'] == 'P' ? 'portrait' : null
		 or $orientation = 'portrait';
		return $orientation;
	}

	public function head() {
		global $theme, $page_type;
		$theme = isset($theme) ? $theme : my_theme();
		$theme = ($theme == 'default' && function_exists('templateDefaultTheme')) ? templateDefaultTheme() : $theme;
		$page_type = function_exists('templatePageType') ? templatePageType() : 'page';
		$head = '';
		ob_start();
		include 'myra/inc/template_head.php';
		$head .= function_exists('templateIncludeCSS') ? templateIncludeCSS() : '';
		$head .= function_exists('templateIncludeJS') ? templateIncludeJS() : '';
		$head .= ob_get_clean();
		return $head;
	}

	public function scripts() {
		// Note: template scripts are not included here as they are html with <script> tags
		// whereas these scripts now get eval'ed by js/myra.template.js.
		global $theme;
		$theme = isset($theme) ? $theme : my_theme();
		$theme = ($theme == 'default' && function_exists('templateDefaultTheme')) ? templateDefaultTheme() : $theme;

		ob_start();
		include 'myra/inc/template_scripts.php';
		$scripts .= ob_get_clean();
		return $scripts;
	}
	public function page() {
		return '<div class="page"></div>';
	}
	public function pageButtons() {
		ob_start();
		include 'myra/inc/page_buttons.php';
		$scripts .= ob_get_clean();
		return $scripts;
	}
	public function header() {
		$header = '';
		ob_start();
		$header .= function_exists('templateIncludeHeader') ? templateIncludeHeader() : '';
		$header .= ob_get_clean();
		return $header;
	}
	public function leftSidebar() {
		$lsidebar = '';
		ob_start();
		$lsidebar .= function_exists('templateIncludeLeftSidebar') ? templateIncludeLeftSidebar() : '';
		$lsidebar .= ob_get_clean();
		return $lsidebar;
	}
	public function content() {
		return '<div class="content"></div';
	}
	public function contentButtons() {
		ob_start();
		include 'myra/inc/content_buttons.php';
		$scripts .= ob_get_clean();
		return $scripts;
	}
	public function editable_begin() {
		// Regular expression for matching the beginning delimiter of the editable part of a file.
		if (function_exists('templateAutoEdit') && templateAutoEdit()) {
			return '<body.*?>';
		}
		else {
			// See note below.
			//return preg_quote($GLOBALS['MYRA_EDIT_DELIMITER_BEGIN'],'/');
			return preg_replace_callback(
				'/(.*>)\s*(<.*)/s',
				create_function('$matches','return preg_quote($matches[1],"/")."\\s*".preg_quote($matches[2],"/");'),
				$GLOBALS['MYRA_EDIT_DELIMITER_BEGIN']);
		}
	}
	public function editable_end() {
		// Regular expression for matching the ending delimiter of the editable part of a file.
		if (function_exists('templateAutoEdit') && templateAutoEdit()) {
			return preg_quote('</body>','/');
		}
		else {
			// Note: the TinyMCE editor puts all comments on a separate line, thereby breaking
			// the pattern we use to find the end of an edit area. Although this should not
			// happen (edit patterns are outside of the editarea edited by TinyMCE), other
			// editors have this habbit too, so I'm keeping this hack.
			//return preg_quote($GLOBALS['MYRA_EDIT_DELIMITER_END'],'/');
			return preg_replace_callback(
				'/(.*>)\s*(<.*)/s',
				create_function('$matches','return preg_quote($matches[1],"/")."\\s*".preg_quote($matches[2],"/");'),
				$GLOBALS['MYRA_EDIT_DELIMITER_END']);
		}
	}
	public function rightSidebar() {
		$rsidebar = '';
		ob_start();
		$rsidebar .= function_exists('templateIncludeRightSidebar') ? templateIncludeRightSidebar() : '';
		$rsidebar .= ob_get_clean();
		return $rsidebar;
	}
	public function footer() {
		$footer = '';
		ob_start();
		$footer .= function_exists('templateIncludeFooter') ? templateIncludeFooter() : '';
		$footer .= ob_get_clean();
		return $footer;
	}

	public function beforeBodyHTML() {
		$html = '';
		$html .= '<div class="page">'."\n";
		$html .= $this->pageButtons();
		$html .= $this->header();
		$html .= $this->leftSidebar();
		$html .= '<div class="content">'."\n";
		$html .= $this->contentButtons();
		if (function_exists('templateAutoEdit') && templateAutoEdit()) $html .= $GLOBALS['MYRA_EDIT_DELIMITER_BEGIN']."\n";
		return $html;
	}

	public function afterBodyHTML() {
		$html = '';
		if (function_exists('templateAutoEdit') && templateAutoEdit()) $html .= $GLOBALS['MYRA_EDIT_DELIMITER_END']."\n";
		$html .= '</div><!-- .content -->'."\n";
		$html .= $this->rightSidebar();
		$html .= $this->footer();
		$html .= '</div><!-- .page -->'."\n";
		return $html;
	}

	/* Event handlers */

	public function beforeNew($html) {
		if (function_exists('templateBeforeNew')) return templateBeforeNew($html);
		return $html;
	}

	public function afterNew() {
		if (function_exists('templateAfterNew')) return templateAfterNew();
	}

	public function beforeSave($html) {
		if (function_exists('templateBeforeSave')) return templateBeforeSave($html);
		return $html;
	}

	public function afterSave() {
		if (function_exists('templateAfterSave')) return templateAfterSave();
	}
}
?>
