<?php

/**
 * User account info
 *
 * This version uses the Apache passwd and groups files to determine user privileges.
 * A user account object can be defined and investigated before the user is authorized.
 */

include_once dirname(__FILE__).'/config.php';

class User {
	private $name = null;
	private $groups = null;

	private $_data = null;
	private $_authenticated = false;
	private $_authorized = false;


	public function __construct($name = null) {
		// Name has to be the name used in Apache htpasswd file to be authenticated.
		$this->name = $name;
	}

	public function authenticate($password=null) {
		if (! $this->is_valid()) return false;

		// Note: This version uses Apache for authentication.
		// That assumes, "if we are here, we are authenticated".
		// We could check $_SERVER['PHP_AUTH_USER'] but PHP does not define it
		// if the current directory is not protected.
		//$this->_authenticated = ($this->password() == $password);
		$this->_authenticated = true;
		return $this->_authenticated;
	}

	public function is_authenticated() {
		return $this->_authenticated ? true : false;
	}

	public function authorize($group=null) {
		if ($group == null) return false;	// require non-null group
		if ($this->groups == null) $this->get_data();
		return in_array($group, $this->groups);
	}

	public function is_authorized($password=null,$group=null) {
		if (! $this->is_valid()) return false;
		if ($password) return ( $this->_authorized = $this->authenticate($password) && $this->authorize($group) );
		if ($group) return ( $this->_authorized = $this->authorize($group) );
		return $this->_authorized ? true : false;
	}
	public function is_valid() {
		if ($this->_data == null) $this->get_data();
		if ($this->_data == null) return false;
		return isset($this->_data['id']) ? true : false;
	}

	public function is_member($group) { return $this->is_authenticated() && $this->authorize($group); }
	public function is_admin() { return $this->is_authenticated() && $this->authorize('admin'); }

	public function is_editor() {
		if (! $this->is_authenticated()) return false;
		if ($GLOBALS['MYRA_EVERYONE_IS_AN_EDITOR']) return true;
		$group = 'editors';
		if ($this->authorize($group)) return true;

		// Check URL path to see if user is an editor of any of the above directories.
		$dirs = preg_split('|/|',strtolower(preg_replace('|/[^/]+$|','',$_SERVER['REQUEST_URI'])));
		foreach ($dirs as $dir) {
			$group .= "-$dir";
			if ($this->authorize($group)) return true;
		}
		return false;
	}

	public function id() { return $this->get('id'); }
	public function username() { return $this->get('username'); }
	// Note: This version uses Apache for authentication so password function not needed.
	//public function password() { return $this->get('password'); }
	public function name() { return $this->get('name'); }

	private function get($item) {
		if ($this->_data == null) $this->get_data();
		if ($this->_data == null) return null;
		if (array_key_exists($item,$this->_data)) return $this->_data[$item];
		return null;
	}
	private function get_data() {
		// Retrieve and cache data
		// Check for existance in Apache password file even though we do not check the passwords here.
		if (preg_match('/^'.$this->name.':/m',file_get_contents($GLOBALS['PASSWORD_FILE']))) {
			$this->_data = array();
			$this->_data['id'] = '000000';		// fake id here mimicking valid database retrieval
			$this->_data['username'] = $this->name;
			// Note: This version uses Apache for authentication so password does not need to be saved.
			// This keeps the plain text password from being saved in session files.
			//$this->_data['password'] = $_SERVER['PHP_AUTH_PW'];
			$this->_data['name'] = $this->name;	// full name not available here

			// Retrieve all groups this user belongs too.
			preg_match_all('/^\\s*(\\w*?)\\s*:.*\\b'.$this->username().'\\b/m',file_get_contents($GLOBALS['GROUP_FILE']),$matches);
			$this->groups = array_flip($matches[1]);
		}
	}
}
?>
