<?php
/*
 * Myra Configuration
 *
 * Default configuration settings.
 */

// The following globals are overridden by the those in the local configuration file.
// Company information.
$GLOBALS['ORG_NAME'] = 'Example Company';			// used in page titles
$GLOBALS['ORG_URL'] = 'http://www.examplecompany.com';	// main url for company (not necessarily this site)
$GLOBALS['ORG_TITLE'] = $GLOBALS['ORG_NAME'].' <small>Portal</small>';	// title for page headers

// Copyright
$GLOBALS['COPYRIGHT'] = '© Example Company, Somewhere, MT';	// displayed in page footer
//$GLOBALS['COPYRIGHT'] = '<a href="http://www.examplecompany.com/copyright.html">© Example Company, Somewhere, MT</a>'; // can also be a link

// Support url
$GLOBALS['SUPPORT_URL'] = 'https://support.examplecompany.com/ticket';	// used in error pages
//$GLOBALS['SUPPORT_URL'] = 'mailto:support@examplecompany.com';	// can also be an email address

// User files
$GLOBALS['USER_FILES'] = '/my-files';	// path prefix to user files
//$GLOBALS['USER_FILES'] = 'https://intranet.examplecompany.com/my-files';	// can also be a url

// User information (HR files)
$GLOBALS['USER_INFO'] = '/my-info';	// path prefix to user files
//$GLOBALS['USER_INFO'] = 'https://intranet.examplecompany.com/my-info';	// can also be a url

// Default theme.
// The default theme name must correspond to a directory name in the MYRA_THEMES_PATH directory.
$GLOBALS['DEFAULT_THEME'] = 'myra';

// Security email
// If defined, anomalies in accessing files and switching contexts are emailed.
//$GLOBALS['SECURITY_EMAIL'] = 'admin@examplecompany.com';

// Define realm name used to authenticate users.
// This is the name that is used in the apache AuthName directive for authenticating users with
// Apache Basic Authentication. The default is the organization's name.
$GLOBALS['AuthName'] = $GLOBALS['ORG_NAME'];
// The logout process presents a login screen to the user. If the user cancels that, the next
// page displayed is the page assigned to AFTER_LOGOUT_URL. This page should NOT be a protected page
// requiring a user to login.
$GLOBALS['AFTER_LOGOUT_URL'] = $GLOBALS['ORG_URL'];


// Myra installation configuration.
// Define the base url. This is the url that corresponds to DOCUMENT_ROOT. This is used to make
// full urls to reference Myra programs in HTML templates where this is not readily available in PHP.
$GLOBALS['BASE_URL'] = 'https://myra.examplecompany.com';

// Define the location of DOCUMENT_ROOT. Normally it is defined in the Apache configuration but the
// DOCUMENT_ROOT used in Myra must not end in '/' as some sysadmins prefer. Also, if Apache is set
// up to use user_dir (http://example.com/~mack/), then DOCUMENT_ROOT must be set to your home directory.
$GLOBALS['DOCUMENT_ROOT'] = preg_replace('|/$|','',$_SERVER['DOCUMENT_ROOT']);

// Path from DocumentRoot where myra web files are located.
//### TODO: test a different path /subdir/myra
$GLOBALS['MYRA'] = '/myra';
$GLOBALS['MYRA_PATH'] = realpath($GLOBALS['DOCUMENT_ROOT'].$GLOBALS['MYRA']);

// Path from DocumentRoot where local site specific configuration settings, images, and
// templates are located. By convention, we locate them in same directory as Myra program
// directory.
$GLOBALS['MYRA_LOCAL'] = '/myra-local';
$GLOBALS['MYRA_LOCAL_PATH'] = realpath($GLOBALS['DOCUMENT_ROOT'].$GLOBALS['MYRA_LOCAL']);

// Define where myra support programs and configurations files are located.
// The path should be outside the location of the web site files.
// By convention, we locate them in the directory above the document root.
$GLOBALS['MYRA_SUPPORT_PATH'] = realpath($GLOBALS['DOCUMENT_ROOT'].'/../myra-support');

// Define where password file and user groups file are located.
// By convention, we locate them in the directory above the document root.
$GLOBALS['PASSWORD_FILE'] = realpath($GLOBALS['DOCUMENT_ROOT'].'/../passwd');
$GLOBALS['GROUP_FILE'] = realpath($GLOBALS['DOCUMENT_ROOT'].'/../group');

// Define URL used to change user's password. By default, Myra changes PASSWORD_FILE defined above.
$GLOBALS['CHANGE_PASSWORD_URL'] = $GLOBALS['MYRA'] . '/password/change-my-password.php';

// Define location of themes.
$GLOBALS['MYRA_THEMES'] = $GLOBALS['MYRA'].'/themes';
$GLOBALS['MYRA_THEMES_PATH'] = realpath($GLOBALS['DOCUMENT_ROOT'].$GLOBALS['MYRA_THEMES']);

// Define location where templates are located.
$GLOBALS['MYRA_TEMPLATES'] = $GLOBALS['MYRA_LOCAL'].'/templates';
$GLOBALS['MYRA_TEMPLATES_PATH'] = realpath($GLOBALS['DOCUMENT_ROOT'].$GLOBALS['MYRA_TEMPLATES']);

// Define the default template to use to construct new files. As HTML templates are dynamically assembled
// around the contents of the HTML file, the default template will be used if one is not specified in the file.
// There must be a directory by this name in the $GLOBALS['MYRA_TEMPLATES'] directory that defines a template.
$GLOBALS['MYRA_TEMPLATE'] = 'document';

// Template variables and these global settings can be inserted into the template pattern file between
// the following delimiters when a new file is made.
$GLOBALS['MYRA_TEMPLATE_DELIMITER_BEGIN'] = '{{';
$GLOBALS['MYRA_TEMPLATE_DELIMITER_END'] = '}}';

// Define patterns used to delimit the editable portions documents.
// The class "editable" needs to be defined for the Javascript edit programs.
$GLOBALS['MYRA_EDIT_DELIMITER_BEGIN'] = '<div class="editable">';
$GLOBALS['MYRA_EDIT_DELIMITER_END'] = '</div><!-- .editable -->';

// Normally editors, those who can change files, are assigned to the "editors" or "editors-path-to-folder" groups
// unless the following global is true in which case everyone is an editor and can change files. This is not
// recommended unless everyone is required to sign in to access the site. 
$GLOBALS['MYRA_EVERYONE_IS_AN_EDITOR'] = false;

// Thumbnail images
$GLOBALS['THUMB_WIDTH'] = 70;
$GLOBALS['THUMB_HEIGHT'] = 70;

// Slide images
$GLOBALS['SLIDE_WIDTH'] = 600;
$GLOBALS['SLIDE_HEIGHT'] = 450;

// Large images
$GLOBALS['IMAGE_WIDTH'] = 1920;
$GLOBALS['IMAGE_HEIGHT'] = 1080;

// Video
$GLOBALS['VIDEO_WIDTH'] = 640;		// 1/2 HD
$GLOBALS['VIDEO_HEIGHT'] = 360;		// 1/2 HD

// Privileges
// Editors as defined in the group file can have their privileges escalated over local file
// privileges so that they can write, delete, or rename files. This assumes the $SUDO configuration
// variable is defined in the MYRA_SUPPORT_PATH/config.sh and that the sudo configuration file
// is properly setup. (see linux visudo command, and myra example files)
// Note: this does not apply to file uploads at this time. Whether an editor or not, the web user
// needs to have write permissions for the target directory.
$GLOBALS['ESCALATE_EDITOR_PRIVILEGES'] = true;

// Folders created by the system will have the following mode (see chmod()).
$GLOBALS['NEW_FOLDER_MODE']=0777;

// Folders created by the system will have the following mode (see chmod()).
$GLOBALS['NEW_FILE_MODE']=0666;

// The index database is usually located in the folder being indexed but can be placed in another
// fixed location.
$GLOBALS['INDEXDB']='';			// ### TODO: test placing index db in a fixed location

// Define the name of the directory used as the index database.
$GLOBALS['INDEXDB_NAME']='.index';	// hidden directory name

// Define settings for support scripts.
// Set following to true to keep archives of changed and deleted files
$GLOBALS['ARCHIVE_FILES'] = true;
$GLOBALS['ARCHIVE_DIR'] = $GLOBALS['MYRA_SUPPORT_PATH'].'/archive';
//$GLOBALS['ARCHIVE_DIR'] = '/var/archive/apache';	// shared archive among apache group

// Support scripts log their actions to the following directory.
$GLOBALS['LOG_DIR'] = $GLOBALS['MYRA_SUPPORT_PATH'].'/logs';

// Set the following to true if using https:// scheme to access website.
// Note: this global is used to determine whether https is used to access the website
// as the PHP $_SERVER['HTTPS'] is unreliable with Basic Authorization (401 pages) and
// mod_autoindex.
$GLOBALS['HTTPS'] = true;	// if true, urls created by the system will use https://

// Debug
// Set the following to true to fill Apache error log file with debug warnings.
$GLOBALS['DEBUG'] = false;
?>
