<?php
/**
 * Common functions
 */

include_once dirname(__FILE__).'/config.php';
include_once dirname(__FILE__).'/class.Session.php';

function bool($str=null) {
	// true/false or yes/no or on/off or 1/0
	if (strlen($str)) return preg_match('/^\s*(n|no|false|off|0+)\s*$/i',$str) ? false : true;
	return false;
}

/* From php.net */
function formatBytes($bytes, $precision = 2) {
	$units = array('B', 'KB', 'MB', 'GB', 'TB'); 

	$bytes = max($bytes, 0); 
	$pow = floor(($bytes ? log($bytes) : 0) / log(1024)); 
	$pow = min($pow, count($units) - 1); 

	// Uncomment one of the following alternatives
	$bytes /= pow(1024, $pow);
	// $bytes /= (1 << (10 * $pow)); 

	return round($bytes, $precision) . ' ' . $units[$pow]; 
}

function rawurlencode_path($url) {
	// encode path components, not /
	$proto = '';
	if (preg_match('|(https?://)|i',$url,$matches)) {
		$proto = $matches[1];
		$url = preg_replace("|$proto|",'',$url,1);
	}

	return $proto . implode("/", array_map("rawurlencode", explode("/", $url)));
}

function is_ajax_request() {
	// Return true if current request is an ajax request.
	if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest') return true;
	// Uncomment next to look for ajax parameter.
	//return bool($_REQUEST['ajax']);
	return false;
}

function is_mobile_device() {
	$ua = strtolower($_SERVER['HTTP_USER_AGENT']);
	// ### TODO: Add Windows mobile detection and others...
	$rtn = false;
	if (preg_match('/android/',$ua) || preg_match('/iphone/',$ua) || preg_match('/ipad/',$ua)) {
		$rtn = true;
	}
	debug("is_mobile_device: return=".($rtn ? 'true' : 'false')."($rtn), _SERVER['HTTP_USER_AGENT']=".$_SERVER['HTTP_USER_AGENT']);
	return $rtn;
}

function browser($ua=null) {
	if ($ua == null) $ua = $_SERVER['HTTP_USER_AGENT'];
	$ub = '';
	// Note: order of checks below is important because of browser spoofing others.
	if(preg_match('/Firefox/i',$ua))	{ $ub = "firefox"; }
	elseif(preg_match('/iPhone/i',$ua))	{ $ub = "iphone"; }
	elseif(preg_match('/iPad/i',$ua))	{ $ub = "ipad"; }
	elseif(preg_match('/Android/i',$ua))	{ $ub = "android"; }
	elseif(preg_match('/Chrome/i',$ua))	{ $ub = "chrome"; }
	elseif(preg_match('/Safari/i',$ua))	{ $ub = "safari"; }
	elseif(preg_match('/Opera/i',$ua))	{ $ub = "opera"; }
	elseif(preg_match('/MSIE/i',$ua))	{ $ub = "ie"; }	
	return $ub;
}

function is_myra_uri($uri = null) {
	// Return true if uri is a myra program uri
	if ($uri === null) $uri = $_SERVER['REQUEST_URI'];	// default is current url
	$uri = preg_replace('|'.my_scheme().'://'.$_SERVER['SERVER_NAME'].'|','',$uri);		// remove hostname from uri
	return preg_match('|^'.$GLOBALS['MYRA'].'/|',$uri);
}

function is_myra_dialog($uri = null) {
	// Return true if uri is a myra program dialog program
	if ($uri === null) $uri = $_SERVER['REQUEST_URI'];	// default is current url
	$uri = preg_replace('|'.my_scheme().'://'.$_SERVER['SERVER_NAME'].'|','',$uri);		// remove hostname from uri
	return preg_match('|^'.$GLOBALS['MYRA'].'/dlg/|',$uri);
}

function curr_dir() {
	static $dir = null;
	if ($dir != null) return $dir;
	if (is_ajax_request()) {
		$session = Session::getInstance();
		$dir = $session->curr_dir;
	}
	else {
		$dir = clean_path(my_path());
		if (!is_dir($dir)) {
			$dir = preg_replace('|(.*)/.*|','$1',$dir);	// in lieu of dirname() which confuses trailing /
		}
	}
	return $dir;
}

function curr_file() {
	static $file = null;
	if ($file != null) return $file;
	if (is_ajax_request()) {
		$session = Session::getInstance();
		$dir = $session->curr_file;
	}
	else {
		$file = clean_path(my_path());
		if (is_dir($file)) $file = '';
		$file = preg_replace('|.*/|','',$file);		// basename();
	}
	return $file;
}

function curr_template() {
	if ($GLOBALS['template']) return $GLOBALS['template'];
	$file = curr_file();
	if ($file && preg_match('/.*\.php$/i',$file)) {
		return 'plain';		// Old default for php templates
	}
	else {
		return $GLOBALS['MYRA_TEMPLATE'];
	}
}

function my_scheme() {
	// The following is unreliable if Apache login screens are used (which downloads 401 page in background).
	//if (! isset($_SERVER['HTTPS'])) {
	//	$_SERVER['HTTPS'] = ($_SERVER['SERVER_PORT'] != 80) ? true : false;	// non-port 80 assumed to be https
	//}
	//return bool($_SERVER['HTTPS']) ? 'https' : 'http';
	return $GLOBALS['HTTPS'] ? 'https' : 'http';
}

function my_url() {
	return my_scheme() . '://' . $_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'];
}

function my_path() {
	// Get current path from $_SERVER['REQUEST_URI'] so that it is accurate when used in Apache mod_autoindex.
	return $GLOBALS['DOCUMENT_ROOT'] . preg_replace('/\?.*/','',rawurldecode($_SERVER['REQUEST_URI']));
}

function clean_path($path,$nodots=false) {
	// Note: do not use realpath() as it dereferences symbolic links.
	// Do remove possible double // in path and trailing /.
	return preg_replace('|/$|','',preg_replace('|//+|','/',($nodots ? preg_replace('|/\.\./|','/',$path) : $path)));
}

function make_url_from_path($path) {
	if (stripos($path, $GLOBALS['DOCUMENT_ROOT'].DIRECTORY_SEPARATOR) == 0) {
		$urlpath = substr($path,strlen($GLOBALS['DOCUMENT_ROOT']));
		if ($urlpath[0] != '/') $urlpath = '/' . $urlpath;
		return my_scheme() . '://' . $_SERVER['SERVER_NAME'] . $urlpath;
	}
	return false;
}

function make_path_from_url($url) {
	$arr = parse_url($url);
	// DOCUMENT_ROOT is only vaid for current domain.
	if ($arr['scheme'] == my_scheme() && $arr['host'] == $_SERVER['SERVER_NAME']) {
		return $GLOBALS['DOCUMENT_ROOT'] . '/' . $arr['path'];
	}
	return '';
}

function token($str) {
	// Create a token from the string which can be used later to validate the string.
	$s = 'Cahlie8gPhie0phojoh7yieK';	// random secret string
	return sha1($str.$s);
}


/**
 * Save and switch between different contexts.
 *
 * Session variables are used across all browser windows, each of which could be
 * pointing to a different directory index. On ajax calls, if the referring url
 * does not correspond to the current directory in the session but the referring url
 * has been previously accessed (and passing security), then the context is switched
 * so the session's current directory corresponds to the referring ajax call.
 *
 * HTML templates put a twist in this as the current file/directory/url is not that of
 * the current url but of the html file url (HTTP_REFERER) that calls ajax/template.php.
 *
 * TODO: make context stuff into a cool class.
 */
function save_context() {
	$session = Session::getInstance();

	$session->curr_dir = curr_dir();
	$session->curr_file = curr_file();
	$session->template = curr_template();
	$session->view_start_time = time();
	$session->context = context_id(my_url());

	// Save current settings into list of contexts that have been seen (and therefore passed security).
	if (! is_array($session->contexts)) $session->contexts = array();
	##$session->contexts[$session->context] = array(
	$_SESSION['contexts'][$session->context] = array(	## patch
			curr_dir => $session->curr_dir,
			curr_file => $session->curr_file,
			template => $session->template,
			view_start_time => $session->view_start_time);
}
function save_template_context($url,$template=null) {
	// HTML templates need to save the context of the referring url.
	if ($template == null) $template = curr_template();
	$session = Session::getInstance();

	$root = parse_url($url,PHP_URL_SCHEME) == 'file' ? '' : $GLOBALS['DOCUMENT_ROOT'];
	$session->curr_dir = $root . dirname(clean_path(parse_url($url,PHP_URL_PATH)));
	$session->curr_file = basename(parse_url($url,PHP_URL_PATH)) or $session->curr_file = '';
	$session->template = $template;
	$session->view_start_time = time();
	$session->context = context_id($url);

	// Save current settings into list of contexts that have been seen (and therefore passed security).
	if (! is_array($session->contexts)) $session->contexts = array();
	##$session->contexts[$session->context] = array(
	$_SESSION['contexts'][$session->context] = array(	## patch
			curr_dir => $session->curr_dir,
			curr_file => $session->curr_file,
			template => $session->template,
			view_start_time => $session->view_start_time);
}
function clear_context() {
	$session = Session::getInstance();

	$session->curr_dir = null;
	$session->curr_file = null;
	$session->template = null;
	$session->view_start_time = time();
	$session->context = context_id(my_url());
}
function create_new_context($folder='',$file='',$template=null) {
	// Create new context for new files and folders.
	if ($template == null) $template = curr_template();
	$session = Session::getInstance();

	if (strlen($folder) > 0) $session->curr_dir = curr_dir() . DIRECTORY_SEPARATOR . clean_path($folder);
	if (strlen($file) > 0) $session->curr_file = $file;
	$session->template = $template;
	$session->view_start_time = time();
	$session->context = context_id(my_url());

	// Save current settings into list of contexts that have been seen (and therefore passed security).
	if (! is_array($session->contexts)) $session->contexts = array();
	##$session->contexts[$session->context] = array(
	$_SESSION['contexts'][$session->context] = array(	## patch
			curr_dir => $session->curr_dir,
			curr_file => $session->curr_file,
			template => $session->template,
			view_start_time => $session->view_start_time);
}
function switch_context($url) {
	// Switch curr_dir and curr_file to correspond with browser window making a request.
	$session = Session::getInstance();

	$context_id = context_id($url);
	## php v5.2.4 does not allow class variables to be arrays yet.
	##if (isset($session->contexts) && isset($session->contexts[$context_id])) {
	if (isset($_SESSION['contexts']) && isset($_SESSION['contexts'][$context_id])) { ## patch
		##$context = $session->contexts[$context_id];
		$context = $_SESSION['contexts'][$context_id];	## patch
		$session->curr_dir = $context['curr_dir'];
		$session->curr_file = $context['curr_file'];
		$session->template = $context['template'];
		$session->view_start_time = $context['view_start_time'];
		$session->context = $context_id;
		debug("switch_context: switched to $context_id");
		return true;
	}
	return false;
}
function context_id($url) {
	return preg_replace('/[?#].*/','',$url);		// strip params and hash off of url
}
function is_context($context_id) {
	## php v5.2.4 does not allow class variables to be arrays yet.
	##if (isset($session->contexts) && isset($session->contexts[$context_id])) {
	return isset($_SESSION['contexts']) && isset($_SESSION['contexts'][$context_id]);
}
function context_exists($url) {
	return is_context(context_id($url));
}

// The folowing contexts are used to save state between dialog forms and ajax functions.
// A dialog form obtains a one-time-use key that refers to a directory/file/timestamp context
// that is transmitted to the ajax program that saves or changes a file in the context identified
// by the key. 
function new_context_key() {
	// Make unique key and save current context to a context that can be accessed only once by the key.
	$static_part = 'MR';		// arbitrary
	$time_part = strval(time());
	$random_part = sprintf("%-05d",mt_rand(0,99999));
	return $static_part.$time_part.$random_part;
}

function new_context() {
	$session = Session::getInstance();
	$key = new_context_key();
	$session->$key = array(
			context => $session->context,
			curr_dir => $session->curr_dir,
			curr_file => $session->curr_file,
			template => $session->template,
			view_start_time => $session->view_start_time,
			client_ip => $_SERVER['REMOTE_ADDR']);
	return $key;
}
function get_context($key,$preserve=false) {
	if (! $key) return null;
	$session = Session::getInstance();
	if (! isset($session->$key)) {
		security("get_context: key not found: $key");
		return null;
	}
	$context = $session->$key;
	if (! $preserve) unset($session->$key);		// allow only one time use;
	if ($context['client_ip'] != $_SERVER['REMOTE_ADDR']) {
		security("get_context: context retrieved from {$_SERVER['REMOTE_ADDR']} but was defined for ip {$context['client_ip']}.");
		return null;
	}
	return $context;
}

function switch_context_to_key($key,$preserve=false) {
	// Switch curr_dir and curr_file to correspond with saved context used to edit files.
	if (! $key) return false;
	$session = Session::getInstance();
	$context = get_context($key,$preserve);
	if (! $context) return false;
	$session->context = $context['context'];
	$session->curr_dir = $context['curr_dir'];
	$session->curr_file = $context['curr_file'];
	$session->template = $context['template'];
	$session->view_start_time = $context['view_start_time'];

	// Check if remote user is the same as the web server user, in which case set to the
	// previously authenticated user. This covers the case when the user is editing a file
	// in a directory that is not "protected" by apache, in which case the remote user name
	// that logged in is not available to the ajax program, so we get the saved user name.
	if ($GLOBALS['REMOTE_USER'] == array_shift(posix_getpwuid(posix_geteuid()))) {
		if ($session->authenticated_user) {
			$GLOBALS['REMOTE_USER'] = $session->authenticated_user;
		}
	}

	debug("switch_context_to_key: $key: {$session->context}");
	return true;
}

/**
 * Sanitize functions.
 */
function sanitize_url($str) {
	// Sanitize url for inclusion into web pages.
	// Remove non-http/s schemas, and <>" characters that might break html attributes.

	$scheme = parse_url($str,PHP_URL_SCHEME);
	if (! ($scheme == '' || preg_match('/https?/i',$scheme)) ) {
		security("sanitize_url: bad url scheme: $scheme: url: $str");
		return '';
	}
	return preg_replace('/[<>"\']/','',$str);
}

function sanitize_html($str) {
	// Sanitize html content for inclusion into web pages.
	// Remove any scripts tags from html (checking for namespaces), including onload and onerror attributes found in img tags.

	// Note: see http://www.howtocreate.co.uk/crosssite.html for a discussion how difficult it is to exclude scripts from html.
	// This routine is used to save html files from the web. It's why everyone should have to sign in before editing files.

	return preg_replace('/onerror=([\'"]).*?\\1/i','',preg_replace('/onload=([\'"]).*?\\1/i','',preg_replace('|<([^>]*:)?script.*?</([^>]*:)?script>|si','',$str)));
}

function sanitize_php($str) {
	// Sanitize php content for saving to files.
	// Remove any php scripts from string
	return preg_replace('/<(php|\?).*?\?>/','',$str);
}

function sanitize_template_name($template) {
	// Allow only letters, digits, spaces, dot and dash to be in theme names.
	return preg_replace('/[^\\w\\s.-]/','',$template);
}

function sanitize_theme_name($theme) {
	// Allow only letters, digits, spaces, dot and dash to be in theme names.
	return preg_replace('/[^\\w\\s.-]/','',$theme);
}

function sanitize_title($title) {
	// Disallow quotes in title tag.
	return preg_replace('/[^\\w\\s~!@#$%^&*()_+={}|:<>?\/.,-]/','',$title);
}

function sanitize_description($description) {
	// Disallow quotes in description.
	return preg_replace('/[^\\w\\s~!@#$%^&*()_+={}|:<>?\/.,-]/','',$description);
}

function sanitize_keywords($keywords) {
	// Allow only letters, digits, spaces, dot, dash and commas to be in keywords for meta tag.
	return preg_replace('/[^\\w\\s.,-]/','',$keywords);
}

function sanitize_email_address($email) {
	// Sanitize mail addresses
	### TODO: Research standard and make this official.
	return preg_replace('/[^\\w<>+@_.,-]/','',$email);
}
function sanitize_filename($filename) {
	// Allow only letters, digits, . and -
	return preg_replace('/[^\\w.-]/','',$filename);
}

/**
 * Themes
 */
function my_theme() {
	static $theme = null;
	if ($theme != null) return $theme;

	// Themes are saved in a cookie or can be specified in url parameters.
	$theme		= isset($_REQUEST['theme'])	? $_REQUEST['theme']	: null
	 or $theme	= isset($_COOKIE['myraTheme'])	? $_COOKIE['myraTheme']	: $GLOBALS['DEFAULT_THEME'];
	$theme = sanitize_theme_name($theme) or $theme = 'default';
	if (isset($_REQUEST['theme']) && ! headers_sent()) {
		// Try and cache theme in cookie.
		// Note that mod_autoindex does not set cookies. This works on php documents, not on indexes.
		setcookie('myraTheme',$theme,time()+60*60*24*365,'/')	// save for 365 days
		 or warn('Cannot save theme setting in cookie. Headers already output.');
		$_COOKIE['myraTheme'] = $theme;
	}
	return $theme;
}

function theme_list() {
	// Return array of filename,file pairs.
	include_once dirname(__FILE__).'/config.php';

	$files = scandir($GLOBALS['MYRA_THEMES_PATH'])
	  or error('Cannot read directory: '.$GLOBALS['MYRA_THEMES_PATH']);
	foreach($files as $file) {
                if (substr($file,0,1) == '.') continue;		// ignore hidden files

		// Uncomment one of the following to eliminate default sym link from list.
		if ($file == 'default') continue;		// skip default link
		//if (is_link($GLOBALS['MYRA_THEMES_PATH'].DIRECTORY_SEPARATOR.$file)) continue;	// themes are only in directories

		if (!is_dir($GLOBALS['MYRA_THEMES_PATH'].DIRECTORY_SEPARATOR.$file)) continue;	// themes are only in directories
                $arr[] = array($file,$file);
        }
	return $arr;
}
function theme_icon($theme) {
	return $GLOBALS['MYRA_THEMES_PATH'].'/'.$theme.'/icon.png';
}
function theme_description($theme) {
	return $GLOBALS['MYRA_THEMES_PATH'].'/'.$theme.'/description.html';
}

/**
 * Templates
 */
function template_list() {
	include_once dirname(__FILE__).'/config.php';

	$files = scandir($GLOBALS['MYRA_TEMPLATES_PATH'])
	  or error('Cannot read directory: '.$GLOBALS['MYRA_TEMPLATES_PATH']);
	foreach($files as $file) {
                if (substr($file,0,1) == '.') continue;		// ignore hidden files
		if (!is_dir($GLOBALS['MYRA_TEMPLATES_PATH'].DIRECTORY_SEPARATOR.$file)) continue;	// templates are only in directories
                $arr[] = array($file,$file);
        }
	return $arr;
}
function template_icon($template) {
	return $GLOBALS['MYRA_TEMPLATES_PATH'].'/'.$template.'/icon.png';
}
function template_description($template) {
	return $GLOBALS['MYRA_TEMPLATES_PATH'].'/'.$template.'/description.html';
}


/**
 * Program flow functions.
 */
function exit_next($url) {
	// Go to next page
	if (false && ! headers_sent()) {
		header("Location: $url");
		exit;
	}
	else {
		// Following causes browser to "blank screen" between pages.
		print <<<End_Of_HTML
<html><head><meta http-equiv="refresh" content="0; url=$url"></head><body></body></html>
End_Of_HTML;
		exit;
	}
}

function exit_error($msg='') {
	trigger_error($msg . backtrace(10),E_USER_WARNING);	// use E_USER_WARNING to avoid death before redirect
	$session = Session::getInstance();
	$session->msg = $msg;
	exit_next($GLOBALS['ERROR_URL']);
}

function exit_dialog_error($msg='') {
	trigger_error($msg . backtrace(10),E_USER_WARNING);	// use E_USER_WARNING to avoid death before redirect
	$session = Session::getInstance();
	$session->msg = $msg;
	exit_next($GLOBALS['ERROR_DIALOG_URL']);
}

function exit_result($success=false,$data=null,$callback=null) {
	// Return json result object to ajax program
	// If callback is specified, a jsonp result object is returned.
	if ($success) {
		$result = array( success => true );
		if ($data != null) {
			if (is_string($data)) {
				 $result['msg'] = $data;
			}
			else {
				$result['data'] = $data;
			}
		}
	}
	else {
		$result = array( success => false );
		if ($data != null) {
			if (is_string($data)) {
				 $result['errmsg'] = $data;
			}
			else {
				$result['data'] = $data;
			}
		}
	}
	$prefix = $suffix = '';
	if ($callback != null) {
		$prefix = "$callback(";
		$suffix = ')';
	}
	header("Content-Type:application/x-javascript");
	echo $prefix . json_encode($result) . $suffix;
	exit;
}

function exit_forbidden($msg='') {
	warn("Forbidden access returned. REFERER=".$_SERVER['HTTP_REFERER'].($msg ? ", ".$msg : ''));
	header("HTTP/1.1 403 Forbidden");
	exit;
}

function error($msg) {
	trigger_error($msg . backtrace(10),E_USER_ERROR);
	// program dies here
}

function warn($msg) {
	trigger_error($msg . backtrace(10),E_USER_WARNING);
}

function debug($msg) {
	if ($GLOBALS['DEBUG']) trigger_error('DEBUG: ' . $msg . backtrace(10),E_USER_WARNING);
}

function sprint_r(&$data) {
	ob_start();
	print_r($data);
	$result = ob_get_contents();
	ob_end_clean();
	return $result;
}

function security($msg) {
	trigger_error("Security>>>>>".$msg . backtrace(10),E_USER_WARNING);

	if ($GLOBALS['SECURITY_EMAIL']) {
		$to = $GLOBALS['SECURITY_EMAIL'];
		$subject = "Myra alert: ".$_SERVER['SERVER_NAME'];
		$body = "$msg\n";
		$body .= "\n--------------------\n\n";
		$body .= "_SERVER:\n";
		$body .= sprint_r($_SERVER);
		//$from = "someonelse@example.com";
		//$headers = "From:" . $from;
		mail($to,$subject,$body,$headers);
	}
}

function backtrace($n=0,$begin=1) {
	// $n: limit number of frames listed
	// $begin: beginning index in stack, not here, but calling function
	$stack = debug_backtrace();
	$where = '';
	for ($i = $begin; $i < count($stack); $i++) {
		if ($n > 0 && $i - $begin >= $n) break;
		$where .= " in " . basename($stack[$i]['file']) . " line " . $stack[$i]['line'] . " (" . $stack[$i]['function'] . "())\n";
	}
	return $where;

}


/******************************************************************************/

/**
 * Proposed common functions from other projects.
 */

function request() {
	// Return array of program true/false requests.
	// Requests can be in the url query string like "request=save" or
	// they can be set by submit buttons <input type="submit" name="save" value="yes">
	// usage: list($new,$edit,$list,$save) = request('new','edit','list','save');
	if (isset($_REQUEST['request']) && ! isset($_REQUEST[strtolower($_REQUEST['request'])])) {
		// Allow url request like request=save
		$_REQUEST[strtolower($_REQUEST['request'])] = 'yes';
	}
	$arr = array();
	$n = func_num_args();
	for ($i = 0; $i < $n; $i++) {
		$arg = func_get_arg($i);
		array_push($arr,bool($_REQUEST[$arg]));
	}
	return $arr;
}

function fullpath($path) {
	// Note: DOCUMENT_ROOT must be set in VirtualHost stanza and
	// all directories in path must be readable by Apache for getcwd().
	if (substr($path,0,1) == '/') {
		//$root = $_SERVER['DOCUMENT_ROOT'];
		$root = $GLOBALS['DOCUMENT_ROOT'];
		return ($root && substr($path,0,strlen($root)) != $root)
			? $root.$path
			: $path;
	}
  	else {
		return getcwd() . '/' . $path;
	}
}

function add_querystring_arg() {
	// usage: add_querystring_arg($url,'arg1','arg2',...);
	// args are strings: "key=value"
	$numargs = func_num_args();
	$url = func_get_arg(0);
	list($url,$anchor) = preg_split('/#/',$url);
	if ($numargs > 1) {
		$url .= (strpos($url,'?') === false) ? '?' : '&';
		$url .= func_get_arg(1);
	}
	for ($i = 2; $i < $numargs; $i++) {
		$url .= func_get_arg($i);
	}
	return $url . ($anchor ? "#$anchor" : '');
}

function remove_querystring_arg() {
	// usage: remove_querystring_arg($url,'arg1','arg2',...);
	$numargs = func_num_args();
	$url = func_get_arg(0);
	list($url,$anchor) = preg_split('/#/',$url);
	list($path,$query) = preg_split('/\?/',$url);
	$args = parse_querystring($query);
	for ($i = 1; $i < $numargs; $i++) {
		$arg = func_get_arg($i);
		if (array_key_exists($arg,$args)) {
			unset($args[$arg]);
		}
	}
	return (count($args) ? "$path?".substr(http_build_query($args),1) : $path) . ($anchor ? "#$anchor" : '');
}

function parse_querystring($querystring) {
	$args = array();
	if (!strlen($querystring)) return $args;
	foreach (split('&',$querystring) as $arg) {
		list($key,$val) = split('=',$arg);
		$args[$key] = $val;
	}
	return $args;
}

function turn_off_magic_quotes() {
	if (get_magic_quotes_gpc()) {
		remove_magic_quotes($_GET);
		remove_magic_quotes($_POST);
		remove_magic_quotes($_COOKIE);
		remove_magic_quotes($_REQUEST);
		ini_set('magic_quotes_gpc', 0);
	}
	set_magic_quotes_runtime(0);
}
function remove_magic_quotes(&$array) {
	if (empty($array)) return;
	foreach (array_keys($array) as $key) {
		if (is_array($array[$key])) {
			remove_magic_quotes($array[$key]);
		}
		else {
			$array[$key] = stripslashes($array[$key]);
		}
	}
}

function obfuscate_email($email) {
	// Simple
	$email = preg_replace('/mailto:/','&#109;ailto&#58;',$email);
	$email = preg_replace('/\@/','&#64;',$email);
	$email = preg_replace('/\./','&#46;',$email);
	return $email;
}

function email_link($email,$name='',$subject='',$body='',$text='',$class='') {
	if (! $email) return '';
	$email = htmlentities($email);
	$name = htmlentities($name);
	$name = preg_replace('/,/','',$name);	// safety, for "..., Jr"

	$param = '';
	if ($subject) { $param .= '?' . 'subject=' . htmlentities($subject); }
	if ($body) { $param .= ($param ? '&amp;' : '?') . 'body=' . htmlentities($body); }

	if ($class) { $class = " class=\"$class\""; }

	if ($name) {
		if (! $text) $text = $name;
		$mailto = obfuscate_email("mailto:$name&lt;$email&gt;");
		return "<a href=\"$mailto$param\"$class>$text</a>";
	}
	else {
		if (! $text) $text = obfuscate_email($email);
		$mailto = obfuscate_email("mailto:$email");
		return "<a href=\"$mailto$param\"$class>$text</a>";
	}
}

function filter_MSOffice($data) {
	// Filter data of formatting codes that MS insists on using to trash HTML clipboard data with.
	if (preg_match('/(MsoNormal|<o:)/',$data)) {		// check if data has MS Office codes
		// remove xml tags
		$data = preg_replace('|<\w+:.*?>|','',$data);	$data = preg_replace('|</\w+:.*?>|','',$data);
		// remove paragraph styles
		$data = preg_replace('|<p.*?>|i','<p>',$data);
		// remove div styles
		$data = preg_replace('|<div style.*?>|i','<div>',$data);
		// remove font tags
		$data = preg_replace('|<font.*?>|i','',$data);	$data = preg_replace('|</font.*?>|','',$data);
		// remove span tags
		$data = preg_replace('|<span.*?>|i','',$data);	$data = preg_replace('|</span.*?>|','',$data);
		// remove blank lines
		$data = preg_replace('#<p[^>]*>(&nbsp;|\s)*</p>\s*#i',"\n",$data);
		$data = preg_replace('#<div[^>]*>(&nbsp;|\s)*</div>\s*#i',"\n",$data);
		// remove double spaces after periods
		$data = preg_replace('|\.&nbsp; |',". ",$data);
	}
	return $data;
}

?>
