<?php
/**
 * Index page functions
 */

include_once dirname(__FILE__).'/class.IndexDb.php';
include_once dirname(__FILE__).'/lib.common.php';
include_once dirname(__FILE__).'/lib.auth.php';

function include_index_header() {
	global $idb;
	if (!$idb) $idb = new IndexDb();
	$contents = $idb->header() or $contents = '';
	$nl = $contents ? "\n" : '';
	echo "\n".'<div class="index-header">'."\n".sanitize_html($contents).$nl.'</div><!-- .index-header -->'."\n";
}

function include_index_footer() {
	global $idb;
	if (!$idb) $idb = new IndexDb();
	$contents = $idb->footer() or $contents = '';
	$nl = $contents ? "\n" : '';
	echo "\n".'<div class="index-footer">'."\n".sanitize_html($contents).$nl.'</div><!-- .index-footer -->'."\n";
}

function include_index_order() {
	global $idb;
	if (!$idb) $idb = new IndexDb();
	$sort_order = $idb->option('thumb-sort-order');
	if ($sort_order) {
		##need php 5.3: echo '<script>myra.thumbSortOrder = '.json_encode($sort_order,JSON_UNESCAPED_SLASHES).'</script>'."\n";
		echo '<script>myra.thumbSortOrder = '.preg_replace('/\\\/','',json_encode($sort_order)).';</script>'."\n";
	}
}

function index_title() {
	global $idb;
	if (!$idb) $idb = new IndexDb();
	$title = $idb->option('title');
	if ($title) {
		return sanitize_title($title);
	}
	return '';
}

function index_meta() {
	global $idb;
	if (!$idb) $idb = new IndexDb();
	$metas = array();
	$description = $idb->option('description');
	if ($description) {
		$metas[] = '<meta name="description" content="'.sanitize_description($description).'" />';
	}
	$keywords = $idb->option('keywords');
	if ($keywords) {
		$metas[] = '<meta name="keywords" content="'.sanitize_keywords($keywords).'" />';
	}
	return join("\n",$metas);
}

function index_upload_file_types() {
	// Return a pipe separated list of file types that can be used in a regular expression.
	if (can_edit_current_dir()) return '.*';	// editors allowed to upload any kind of file
	global $idb;
	if (!$idb) $idb = new IndexDb();
	if (!$idb->option('guest_can_upload')) return '';
	$file_types = array();
	// Common files types from http://www.fileinfo.com/filetypes used.
	if ($idb->option('upload_allow_anything')) {
		$file_types[] = '.*';
	}
	else {
		if ($idb->option('upload_allow_images')) $file_types[] = 'png|gif|jpg|jpeg|tiff|tif|bmp|pdf|ai|eps|svg|drw|dxf|pat|vsd';
		if ($idb->option('upload_allow_documents')) $file_types[] = 'doc|docx|xls|xlsx|ods|ots|odt|ott|ps|mdb|dbf|dif|pub|zip|tar|tgz|qbw|qbb|xml|htm|html';
		if ($idb->option('upload_allow_video')) $file_types[] = 'mpg|mov|mp4|wmv|rm|flv|swf|qt';
		if ($idb->option('upload_allow_music')) $file_types[] = 'wav|aif|mp3|mid|wma|iff|ra';
		$file_types[] = 'txt|csv';		// default
	}
	return join('|',$file_types);
}

function index_upload_notify($dir,$files) {
	// Email upload results
	if (!count($files)) return;
	global $idb;
	if (!$idb) $idb = new IndexDb();
	if ( ($to = $idb->option('upload_notify_email')) ) {
		$url = make_url_from_path($dir) or $url = $dir;

                $subject = "File upload notification: ".$_SERVER['SERVER_NAME'];
                $body = 'The following files have been uploaded to directory '.$url.($_SERVER['PHP_AUTH_USER'] ? ' by '.$_SERVER['PHP_AUTH_USER'] : '')."\n";
                $body .= "\n--------------------\n\n";
		$body .= join("\n",preg_replace('/c:.fakepath./i','',$files));
                $body .= "\n\n--------------------\n\n";
		$body .= "You are receiving this email because settings in $url request email notification be sent to this address when files are uploaded.\n";
                //$from = "someonelse@example.com";
                //$headers = "From:" . $from;
                mail($to,$subject,$body,$headers);
        }
}

function is_gallery_default_view() {
	global $idb;
	if (!$idb) $idb = new IndexDb();
	return $idb->option('gallery_default_view') ? true : false;
}
?>
