/* 
Simple JQuery accordion menu.

Each menu MUST have a class 'accordion' set.
If you want a panel to be expanded at page load, give the containing LI element the classname 'expand'.
Optional extra classnames for the UL element that holds an accordion:
  noaccordion :	no accordion functionality
  collapsible :	menu can be fully collapsed, useful on top level <ul> which is by default left open.

<div class="accordion">
<ul [optional class] [optional class]">
<li><a href="#">Sub menu heading</a>
<ul>
<li><a href="http://site.com/">Link</a></li>
<li><a href="http://site.com/">Link</a></li>
<li><a href="http://site.com/">Link</a></li>
...
...
</ul>
// This item is open at page load time
<li class="expand"><a href="#">Sub menu heading</a>
<ul>
<li><a href="http://site.com/">Link</a></li>
<li><a href="http://site.com/">Link</a></li>
<li><a href="http://site.com/">Link</a></li>
...
</ul>
...
</ul>
</div>

Copyright 2007-2010 by Marco van Hylckama Vlieg
web: http://www.i-marco.nl/weblog/
email: marco@i-marco.nl
Free to use any way you like.
*/

/*
 * Modified 6/11/2011 by Mack Pexton (mackpexton.com)
 * - Attached click handler to <li> tags instead of enclosed <a> tags.
 * - More than 2 levels of menus accommodated and expanded if needed.
 * - Submenus/panels to open/close are required to have "acitem" class.
 * - Added localization of $ to avoid collisions with other frameworks
 * - Requires jQuery v1.4.
 * - Cleaned up, change names slightly
 * - Menus automatically setup now have to be in a container with a class "accordion".
 */

(function($){
	$.fn.setupAccordionMenu = function(){
		return this.each(function(){
			$('.acitem', this).hide();
			$('li.expand', this).each(function(){
				$('.acitem',this).first().addClass('active').show();
				$(this).addClass('active').parentsUntil('.accordion').each(function(){
					if ($(this).hasClass('acitem')) $(this).addClass('active').show();
					if ($(this).is('li')) $(this).addClass('active');
				});
			});
			$('li', this).click(function(e){
				if (e.target != this && e.target.nodeName == 'A') return true;	// execute A tags
				var parent = this.parentNode, $first = $('.acitem', this).first();
				if ($first.length <= 0) return false;
				if ($('.acitem',parent).is(':animated')) return false;
				if ($(parent).hasClass('noaccordion')) {
					$first.slideToggle('normal', function(){
						if ($(this).is(':visible')) {
							$(this).closest('li').addClass('active');
						}
						else {
							$(this).closest('li').removeClass('active');
						}    
					});
				}
				else {
					if ($first.hasClass('acitem')) {
						if ($first.is(':visible')) {
							if ($(parent).hasClass('collapsible')) {
								$('.acitem:visible', parent).first().slideUp('normal', function(){
									$(this).closest('li').removeClass('active');
								});
							}
						}
						else {
							$('.acitem:visible', parent).first().slideUp('normal', function(){
								$(this).closest('li').removeClass('active');
							});
							$first.closest('li').addClass('active');
							$first.slideDown('normal');
						}
					}
				}
				return false;
			});
		});
		return this;
	};
	$(function(){$('.accordion>ul').setupAccordionMenu();});
})(jQuery);
