#!/bin/bash

#
# Config file for myra support scripts
#
# Usage:
# . "$(dirname $0)/config.sh"

# The following variables need to be set the same as the global variables of the 
# same name in myra/lib/config.inc.php.

if [ -z "$MYRA_PATH" -o -z "$MYRA_SUPPORT_PATH" ]
then
	# The following configuration settings are assumed to be set in the php config
	# files and exported in the environment for these scripts. If using sudo then
	# these variables need to be passed to the sudo environment (see sudoers(5)) or
	# they need to be set here.

	export MYRA_PATH=/var/www/html/myra		# web site location
	export MYRA_LOCAL_PATH=/var/www/html/myra-local	# web site location
	export MYRA_SUPPORT_PATH=/var/www/myra-support	# location outside of web site

	# Company info
	export ORG_NAME="Example Company"		# full name

	# Set user name to use in logs. Should be set upon web site login.
	export REMOTE_USER=${REMOTE_USER:-$(id -run)}

	# Set location of password and group file for web site access.
	export PASSWORD_FILE=$MYRA_SUPPORT_PATH/../passwd
	export GROUP_FILE=$MYRA_SUPPORT_PATH/../group

	# Set modes for new files and folders (see chmod(1)). The modes are octal as used by PHP.
	export NEW_FOLDER_MODE=0777
	export NEW_FILE_MODE=0666

	# Set location of index database and its name.
	export INDEXDB=''
	export INDEXDB_NAME='.index'
	
	# Set location of archive. It must be writable by web user as there is no escalation of privileges.
	export ARCHIVE_DIR=${ARCHIVE_DIR:-"$MYRA_SUPPORT_PATH/archive"}

	# Set location of script logs. It must be writable by web user.
	export LOG_DIR=${LOG_DIR:-"$MYRA_SUPPORT_PATH/logs"}

	# Set flag to use sudo or not.
	export USE_SUDO=1

	# Comment out the following for testing.
	exit;
fi

#
# Log files
#

export PROGNAME=${PROGNAME:-$(basename $0)}
export LOGFILE="$LOG_DIR/$PROGNAME"			# undefine to turn off logging

#
# Script globals
#

export PATH=$MYRA_SUPPORT_PATH/scripts/:/bin:/usr/bin

# Uncomment the next if using sudo to escalate privileges to make index work files.
# See instructions in README.txt on how to set up sudo privileges.
[ "$USE_SUDO" ] && export SUDO=/usr/bin/sudo

#
# File maintenance scripts
#

# Set name of archive program on client servers used to save file versions before changes.
export ARCHIVER=$MYRA_SUPPORT_PATH/scripts/archive_file	# used to save archive of file before removing

# Set flag
export I_AM_CONFIGURED=yes
